@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2020 The Cacti Group                                 |
+ | Copyright (C) 2004-2021 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -23,7 +23,7 @@
 */
 
 /* include ldap support */
-include_once('./lib/ldap.php');
+include_once(__DIR__ . '/lib/ldap.php');
 
 /* set default action */
 set_default_action();
@@ -66,7 +66,7 @@ if (read_config_option('auth_method') == '2') {
 		$records = file($mapfile);
 		$found   = false;
 
-		if (sizeof($records)) {
+		if (cacti_sizeof($records)) {
 			foreach($records as $r) {
 				list($basic, $shortform) = str_getcsv($r);
 
@@ -362,6 +362,14 @@ if (get_nfilter_request_var('action') == 'login') {
 			exit;
 		}
 
+		if (!auth_user_has_access($user)) {
+			/* error */
+			display_custom_error_message(__('You do not have access to any area of Cacti.  Contact your administrator.'));
+			cacti_log(sprintf("LOGIN: User %s with id %s does not have access to any area of Cacti", $user['username'], $user['id']), false, 'AUTH');
+			header('Location: index.php?header=false');
+			exit;
+		}
+
 		/* remember this user */
 		if (isset_request_var('remember_me') && read_config_option('auth_cache_enabled') == 'on') {
 			set_auth_cookie($user);
@@ -397,7 +405,7 @@ if (get_nfilter_request_var('action') == 'login') {
 	} elseif (!$guest_user && $user_auth) {
 		/* No guest account defined */
 		display_custom_error_message(__('Access Denied, please contact you Cacti Administrator.'));
-		cacti_log('LOGIN: Access Denied, No guest enabled or template user to copy', false, 'AUTH');
+		cacti_log('LOGIN: Access Denied, Either Guest account is not enabled or there is no User Template defined to copy', false, 'AUTH');
 		header('Location: index.php');
 		exit;
 	} else {
@@ -423,6 +431,55 @@ if (get_nfilter_request_var('action') == 'login') {
 	}
 }
 
+function auth_user_has_access($user) {
+	$access = false;
+
+	// See if they have access to any realms
+	$realms = db_fetch_cell_prepared('SELECT COUNT(*)
+		FROM user_auth_realm
+		WHERE user_id = ?',
+		array($user['id']));
+
+	if ($realms > 0) {
+		return true;
+	}
+
+	// See if they have general graph access as a guest account
+	if (read_config_option('guest_user') > 0) {
+		if ($user['show_tree'] == 'on' || $user['show_list'] == 'on' || $user['show_preview'] == 'on') {
+			return true;
+		}
+	}
+
+	// See if they have access to any group realms
+	$user_groups = db_fetch_assoc_prepared('SELECT *
+		FROM user_auth_group_members
+		WHERE user_id = ?',
+		array($user['id']));
+
+	if (cacti_sizeof($user_groups)) {
+		foreach($user_groups as $g) {
+			$realms = db_fetch_cell_prepared('SELECT COUNT(*)
+				FROM user_auth_group_realm
+				WHERE group_id = ?',
+				array($g['group_id']));
+
+			if ($realms > 0) {
+				return true;
+			}
+
+			// See if they have general graph access as a guest account
+			if (read_config_option('guest_user') > 0) {
+				if ($g['show_tree'] == 'on' || $g['show_list'] == 'on' || $g['show_preview'] == 'on') {
+					return true;
+				}
+			}
+		}
+	}
+
+	return false;
+}
+
 /* auth_display_custom_error_message - displays a custom error message to the browser that looks like
    the pre-defined error messages
    @arg $message - the actual text of the error message to display
@@ -569,7 +626,7 @@ function domains_login_process() {
 	}
 }
 
-function domains_ldap_auth($username, $password = '', $dn = '', $realm) {
+function domains_ldap_auth($username, $password = '', $dn = '', $realm = 0) {
 	$ldap = new Ldap;
 
 	if (!empty($username)) $ldap->username = $username;
