@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2021 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -577,7 +577,7 @@ function settings_javascript() {
 
 							if (id != undefined) {
 								$.get('auth_profile.php?tab='+currentTab+'&action=reset_default&name='+id, function(data) {
-									if (id != 'selected_theme' && id != 'user_language') {
+									if (id != 'selected_theme' && id != 'user_language' && id != 'enable_hscroll') {
 										if ($('#'+id).is(':checkbox')) {
 											if (data == 'on') {
 												$('#'+id).prop('checked', true);
@@ -616,7 +616,10 @@ function settings_javascript() {
 				value = $(this).val();
 			}
 
-			$.get('auth_profile.php?tab='+currentTab+'&action=update_data&name='+name+'&value='+value, function() {
+			$.post('auth_profile.php?tab='+currentTab+'&action=update_data', {
+				__csrf_magic: csrfMagicToken,
+				name: name,
+				value: value
 			});
 		}).change(function() {
 			name  = $(this).attr('id');
@@ -630,8 +633,12 @@ function settings_javascript() {
 				value = $(this).val();
 			}
 
-			$.get('auth_profile.php?tab='+currentTab+'&action=update_data&name='+name+'&value='+value, function() {
-				if (name == 'selected_theme' || name == 'user_language') {
+			$.post('auth_profile.php?tab='+currentTab+'&action=update_data', {
+				__csrf_magic: csrfMagicToken,
+				name: name,
+				value: value
+				}, function() {
+				if (name == 'selected_theme' || name == 'user_language' || name == 'enable_hscroll') {
 					document.location = 'auth_profile.php?action=edit';
 				}
 			});
