@@ -1,8 +1,8 @@
-#!/usr/bin/php -q
+#!/usr/bin/env php
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2021 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -34,6 +34,7 @@ global $debug;
 $debug   = false;
 $form    = '';
 $force   = false;
+$rtables = false;
 $dynamic = false;
 
 if (cacti_sizeof($parms)) {
@@ -50,6 +51,9 @@ if (cacti_sizeof($parms)) {
 			case '--debug':
 				$debug = true;
 				break;
+			case '--tables':
+				$rtables = true;
+				break;
 			case '--force':
 				$force = true;
 				break;
@@ -83,16 +87,18 @@ db_execute('UNLOCK TABLES');
 
 $tables = db_fetch_assoc('SHOW TABLES FROM ' . $database_default);
 
-if (cacti_sizeof($tables)) {
-	foreach($tables AS $table) {
-		print "Repairing Table -> '" . $table['Tables_in_' . $database_default] . "'";
-		$status = db_execute('REPAIR TABLE ' . $table['Tables_in_' . $database_default] . $form);
-		print ($status == 0 ? ' Failed' : ' Successful') . "\n";
-
-		if ($dynamic) {
-			print "Changing Table Row Format to Dynamic -> '" . $table['Tables_in_' . $database_default] . "'";
-			$status = db_execute('ALTER TABLE ' . $table['Tables_in_' . $database_default] . ' ROW_FORMAT=DYNAMIC');
+if ($rtables) {
+	if (cacti_sizeof($tables)) {
+		foreach($tables AS $table) {
+			print "Repairing Table -> '" . $table['Tables_in_' . $database_default] . "'";
+			$status = db_execute('REPAIR TABLE ' . $table['Tables_in_' . $database_default] . $form);
 			print ($status == 0 ? ' Failed' : ' Successful') . "\n";
+
+			if ($dynamic) {
+				print "Changing Table Row Format to Dynamic -> '" . $table['Tables_in_' . $database_default] . "'";
+				$status = db_execute('ALTER TABLE ' . $table['Tables_in_' . $database_default] . ' ROW_FORMAT=DYNAMIC');
+				print ($status == 0 ? ' Failed' : ' Successful') . "\n";
+			}
 		}
 	}
 }
@@ -268,6 +274,7 @@ function display_help () {
 	print "Optional:\n";
 	print "    --dynamic - Convert a table to Dynamic row format if available\n";
 	print "    --form    - Force rebuilding the indexes from the database creation syntax.\n";
+	print "    --tables  - Repair Tables as well as possible database corruptions.\n";
 	print "    --force   - Remove Invalid Template records from the database.\n";
 	print "    --debug   - Display verbose output during execution.\n\n";
 }
