@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2020 The Cacti Group                                 |
+ | Copyright (C) 2004-2021 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -570,6 +570,7 @@ function data_query_item_remove_confirm() {
 		<td class='right'>
 			<input type='button' class='ui-button ui-corner-all ui-widget' id='cancel' value='<?php print __esc('Cancel');?>' onClick='$("#cdialog").dialog("close");' name='cancel'>
 			<input type='button' class='ui-button ui-corner-all ui-widget' id='continue' value='<?php print __esc('Continue');?>' name='continue' title='<?php print __esc('Remove Data Query Graph Template');?>'>
+			<input type='hidden' id='snmp_query_graph_id' value='<?php print get_request_var('id');?>'>
 		</td>
 	</tr>
 	<?php
@@ -851,6 +852,13 @@ function data_query_item_edit() {
 					AND data_template_id = ?
 					ORDER BY field_name, sequence', array(get_request_var('id'), $data_template['id']));
 
+				$name = db_fetch_cell_prepared('SELECT name
+					FROM data_template
+					WHERE id = ?',
+					array($data_template['id']));
+
+				print "<tr class='tableHeader'><td colspan='4'>" . html_escape($name) . '</td></tr><tr>';
+
 				html_header(array(
 					array('display' => __('Name'), 'align' => 'left'),
 					array('display' => __('Order'), 'align' => 'center'),
@@ -1172,6 +1180,9 @@ function data_query_edit() {
 	?>
 	<script type='text/javascript'>
 
+	var snmp_query_id = '<?php print isset($snmp_query['id']) ? $snmp_query['id']:'0';?>';
+	var snmp_query_graph_id = '<?php print isset($snmp_query_graph['id']) ? $snmp_query_graph['id']:'0';?>';
+
 	$(function() {
 		$('.cdialog').remove();
 		$('#main').append("<div id='cdialog' class='cdialog'></div>");
@@ -1191,11 +1202,11 @@ function data_query_edit() {
 					$('#continue').click(function(data) {
 						$.post('data_queries.php?action=item_remove', {
 							__csrf_magic: csrfMagicToken,
-							snmp_query_id: <?php print $snmp_query['id'];?>,
-							id: <?php print $snmp_query_graph['id'];?>
+							snmp_query_id: snmp_query_id,
+							id: $('#snmp_query_graph_id').val()
 						}, function(data) {
 							$('#cdialog').dialog('close');
-							loadPageNoHeader('data_queries.php?action=edit&header=false&id=<?php print $snmp_query['id'];?>');
+							loadPageNoHeader('data_queries.php?action=edit&header=false&id='+snmp_query_id);
 						});
 					});
 
