@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2020 The Cacti Group                                 |
+ | Copyright (C) 2004-2021 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -24,6 +24,7 @@
 
 include('./include/auth.php');
 include_once('./lib/api_graph.php');
+include_once('./lib/api_data_source.php');
 include_once('./lib/api_tree.php');
 include_once('./lib/html_tree.php');
 include_once('./lib/poller.php');
@@ -238,9 +239,6 @@ function form_actions() {
 					db_execute('DELETE FROM snmp_query_graph_rrd_sv
 						WHERE snmp_query_graph_id IN (' . implode(', ', $snmp_graph_ids) . ')');
 
-					db_execute('DELETE FROM snmp_query_graph_rrd_sv
-						WHERE snmp_query_graph_id IN (' . implode(', ', $snmp_graph_ids) . ')');
-
 					db_execute('DELETE FROM snmp_query_graph_sv
 						WHERE snmp_query_graph_id IN (' . implode(', ', $snmp_graph_ids) . ')');
 				}
@@ -829,7 +827,7 @@ function template() {
 		)
 	);
 
-	$nav = html_nav_bar('graph_templates.php?filter=' . get_request_var('filter'), MAX_DISPLAY_PAGES, get_request_var('page'), $rows, $total_rows, sizeof($display_text) + 1, __('Graph Templates'), 'page', 'main');
+	$nav = html_nav_bar('graph_templates.php?filter=' . get_request_var('filter'), MAX_DISPLAY_PAGES, get_request_var('page'), $rows, $total_rows, cacti_sizeof($display_text) + 1, __('Graph Templates'), 'page', 'main');
 
 	form_start('graph_templates.php', 'chk');
 
