@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2020 The Cacti Group                                 |
+ | Copyright (C) 2004-2021 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -30,6 +30,7 @@ include_once('./lib/data_query.php');
 include_once('./lib/html_form_template.php');
 include_once('./lib/html_graph.php');
 include_once('./lib/sort.php');
+include_once('./lib/snmp.php');
 include_once('./lib/poller.php');
 include_once('./lib/template.php');
 include_once('./lib/utility.php');
@@ -421,7 +422,7 @@ function graphs() {
 								<?php
 								if (cacti_sizeof($item_rows) > 0) {
 									foreach ($item_rows as $key => $value) {
-										print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . html_escape($value) . "</option>\n";
+										print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . html_escape($value) . '</option>';
 									}
 								}
 								?>
@@ -462,9 +463,19 @@ function graphs() {
 	}
 
 	if (get_request_var('graph_type') > 0) {
+		/* validate the page filter */
+		if (isset_request_var('page' . get_request_var('graph_type'))) {
+			get_filter_request_var('page' . get_request_var('graph_type'));
+		}
+
 		load_current_session_value('page' . get_request_var('graph_type'), 'sess_grn_page' . get_request_var('graph_type'), '1');
 	}else if (get_request_var('graph_type') == -2) {
 		foreach($snmp_queries as $query) {
+			/* validate the page filter */
+			if (isset_request_var('page' . $query['id'])) {
+				get_filter_request_var('page' . $query['id']);
+			}
+
 			load_current_session_value('page' . $query['id'], 'sess_grn_page' . $query['id'], '1');
 		}
 	}
@@ -478,8 +489,8 @@ function graphs() {
 
 		print "<tr class='tableHeader'>
 				<th class='tableSubHeaderColumn'>" . __('Graph Template Name') . "</th>
-				<th class='tableSubHeaderCheckbox'><input class='checkbox' type='checkbox' id='all_cg' title='" . __esc('Select All') . "' onClick='selectAll(\"sg\",this.checked)'><label class='formCheckboxLabel' title='" . __esc('Select All Rows'). "' for='all_cg'></label></th>\n
-			</tr>\n";
+				<th class='tableSubHeaderCheckbox'><input class='checkbox' type='checkbox' id='all_cg' title='" . __esc('Select All') . "' onClick='selectAll(\"sg\",this.checked)'><label class='formCheckboxLabel' title='" . __esc('Select All Rows'). "' for='all_cg'></label></th>
+			</tr>";
 
 		if (get_request_var('filter') != '') {
 			$sql_where = 'AND gt.name LIKE ' . db_qstr('%' . get_request_var('filter') . '%');
@@ -547,18 +558,17 @@ function graphs() {
 
 		html_start_box('', '100%', '', '3', 'center', '');
 
-		$available_graph_templates = db_fetch_assoc_prepared('
-			(
-				SELECT graph_templates.id, graph_templates.name
-				FROM graph_templates
-				LEFT JOIN snmp_query_graph
-				ON snmp_query_graph.graph_template_id = graph_templates.id
-				WHERE snmp_query_graph.name IS NULL
-				AND graph_templates.id NOT IN (SELECT graph_template_id FROM host_graph WHERE host_id = ?)
-				AND graph_templates.multiple = ""
-			) UNION (
-				SELECT id, name FROM graph_templates WHERE multiple = "on"
-			)
+		$available_graph_templates = db_fetch_assoc_prepared('SELECT graph_templates.id, graph_templates.name
+			FROM graph_templates
+			LEFT JOIN snmp_query_graph
+			ON snmp_query_graph.graph_template_id = graph_templates.id
+			WHERE snmp_query_graph.name IS NULL
+			AND graph_templates.id NOT IN (SELECT graph_template_id FROM host_graph WHERE host_id = ?)
+			AND graph_templates.multiple = ""
+			UNION
+			SELECT id, name
+			FROM graph_templates
+			WHERE multiple = "on"
 			ORDER BY name',
 			array(get_request_var('host_id'))
 		);
@@ -626,7 +636,8 @@ function graphs() {
 					snmp_query_graph.id,snmp_query_graph.name
 					FROM snmp_query_graph
 					WHERE snmp_query_graph.snmp_query_id = ?
-					ORDER BY snmp_query_graph.name', array($snmp_query['id']));
+					ORDER BY snmp_query_graph.name',
+					array($snmp_query['id']));
 
 				if (cacti_sizeof($snmp_query_graphs)) {
 					foreach ($snmp_query_graphs as $snmp_query_graph) {
@@ -651,7 +662,7 @@ function graphs() {
 					}
 				}
 
-				print "<div class='cactiTable'><div><div class='cactiTableTitle'><span>" . __esc('Data Query [%s]', $snmp_query['name']) . "</span></div><div class='cactiTableButton'><span class='reloadquery fa fa-sync' id='reload" . $snmp_query['id'] . "' data-id='" . $snmp_query['id'] . "'></span></div></div></div>\n";
+				print "<div class='cactiTable'><div><div class='cactiTableTitle'><span>" . __esc('Data Query [%s]', $snmp_query['name']) . "</span></div><div class='cactiTableButton'><span class='reloadquery fa fa-sync' id='reload" . $snmp_query['id'] . "' data-id='" . $snmp_query['id'] . "'></span></div></div></div>";
 
 				if ($xml_array != false) {
 					$html_dq_header = '';
@@ -760,7 +771,7 @@ function graphs() {
 							if (($field_array['direction'] == 'input' || $field_array['direction'] == 'input-output') && cacti_sizeof($field_names)) {
 								foreach($field_names as $row) {
 									if ($row['field_name'] == $field_name) {
-										$html_dq_header .= "<th class='tableSubHeaderColumn'>" . $field_array['name'] . "</th>\n";
+										$html_dq_header .= "<th class='tableSubHeaderColumn'>" . $field_array['name'] . '</th>';
 										break;
 									}
 								}
@@ -768,12 +779,12 @@ function graphs() {
 						}
 
 						if (!cacti_sizeof($snmp_query_indexes)) {
-							print "<tr class='odd'><td>" . __('This Data Query returned 0 rows, perhaps there was a problem executing this Data Query.') . "<a href='" . html_escape('host.php?action=query_verbose&header=true&id=' . $snmp_query['id'] . '&host_id=' . $host['id']) . "'>" . __('You can run this Data Query in debug mode') . "</a> " . __('From there you can get more information.') . "</td></tr>\n";
+							print "<tr class='odd'><td>" . __('This Data Query returned 0 rows, perhaps there was a problem executing this Data Query.') . "<a href='" . html_escape('host.php?action=query_verbose&header=true&id=' . $snmp_query['id'] . '&host_id=' . $host['id']) . "'>" . __('You can run this Data Query in debug mode') . "</a> " . __('From there you can get more information.') . '</td></tr>';
 						} else {
 							print "<tr class='tableHeader'>
 									$html_dq_header
-									<th class='tableSubHeaderCheckbox'><input class='checkbox' id='all_" . $snmp_query['id'] . "' type='checkbox' name='all_" . $snmp_query['id'] . "' title='" . __esc('Select All') . "' onClick='selectAll(\"sg_" . $snmp_query['id'] . "\",this.checked)'><label class='formCheckboxLabel' title='" . __esc('Select All Rows'). "' for='all_" . $snmp_query['id'] . "'></label></th>\n
-								</tr>\n";
+									<th class='tableSubHeaderCheckbox'><input class='checkbox' id='all_" . $snmp_query['id'] . "' type='checkbox' name='all_" . $snmp_query['id'] . "' title='" . __esc('Select All') . "' onClick='selectAll(\"sg_" . $snmp_query['id'] . "\",this.checked)'><label class='formCheckboxLabel' title='" . __esc('Select All Rows'). "' for='all_" . $snmp_query['id'] . "'></label></th>
+								</tr>";
 						}
 
 						$row_counter    = 0;
@@ -790,7 +801,7 @@ function graphs() {
 									if ($field_array['direction'] == 'input' || $field_array['direction'] == 'input-output') {
 										if (in_array($field_name, $fields)) {
 											if (isset($row[$field_name])) {
-												print "<td><span class='textOverflow' id='text$query_row" . '_' . $column_counter . "'>" . filter_value($row[$field_name], get_request_var('filter')) . '</span></td>';
+												print "<td title='" . html_escape($row[$field_name]) . "'><span class='textOverflow' id='text$query_row" . '_' . $column_counter . "'>" . filter_value($row[$field_name], get_request_var('filter')) . '</span></td>';
 											} else {
 												print "<td><span class='textOverflow' id='text$query_row" . '_' . $column_counter . "'></span></td>";
 											}
@@ -803,7 +814,7 @@ function graphs() {
 								print "<td style='width:1%;' class='checkbox'>";
 								print "<input class='checkbox' type='checkbox' name='sg_$query_row' id='sg_$query_row'><label class='formCheckboxLabel' for='sg_$query_row'></label>";
 								print '</td>';
-								print "</tr>\n";
+								print '</tr>';
 
 								$row_counter++;
 							}
@@ -811,12 +822,12 @@ function graphs() {
 					} else {
 						html_start_box('', '100%', '', '3', 'center', '');
 
-						print "<tr class='odd'><td class='textError'>" . __('Search Returned no Rows.') . "</td></tr>\n";
+						print "<tr class='odd'><td class='textError'>" . __('Search Returned no Rows.') . '</td></tr>';
 					}
 				} else {
 					html_start_box('', '100%', '', '3', 'center', '');
 
-					print "<tr class='odd'><td class='textError'>" . __('Error in data query.') . "</td></tr>\n";
+					print "<tr class='odd'><td class='textError'>" . __('Error in data query.') . '</td></tr>';
 				}
 
 				html_end_box(false);
@@ -829,9 +840,9 @@ function graphs() {
 					ORDER BY snmp_query_graph.name', array($snmp_query['id']));
 
 				if (cacti_sizeof($data_query_graphs) == 1) {
-					echo "<input type='hidden' id='sgg_" . $snmp_query['id'] . "' name='sgg_" . $snmp_query['id'] . "' value='" . $data_query_graphs[0]['id'] . "'>\n";
+					echo "<input type='hidden' id='sgg_" . $snmp_query['id'] . "' name='sgg_" . $snmp_query['id'] . "' value='" . $data_query_graphs[0]['id'] . "'>";
 				} elseif (cacti_sizeof($data_query_graphs) > 1) {
-					print "<div class='break'></div>\n";
+					print "<div class='break'></div>";
 
 					html_start_box('', '100%', '', '3', 'center', '');
 
@@ -852,7 +863,7 @@ function graphs() {
 								"; html_create_list($data_query_graphs, 'name', 'id', $selected); print "
 							</select>
 						</td>
-					</tr>\n";
+					</tr>";
 
 					html_end_box(false);
 				}
@@ -863,7 +874,7 @@ function graphs() {
 	}
 
 	if ($script != '') {
-		$script .= "$('.default').click(function() { $.get('graphs_new.php?action=ajax_save&query=" . (isset($snmp_query['id']) ? $snmp_query['id']:'') . "'+'&item='+$(\".dqselect\").val()).fail(function(data) { getPresentHTTPError(data); });});</script>\n";
+		$script .= "$('.default').click(function() { $.get('graphs_new.php?action=ajax_save&query=" . (isset($snmp_query['id']) ? $snmp_query['id']:'') . "'+'&item='+$(\".dqselect\").val()).fail(function(data) { getPresentHTTPError(data); });});</script>";
 		print $script;
 	}
 
@@ -875,7 +886,7 @@ function graphs() {
 	}
 
 	if (isset($_SERVER['HTTP_REFERER']) && !substr_count($_SERVER['HTTP_REFERER'], 'graphs_new')) {
-		set_request_var('returnto', basename(sanitize_uri($_SERVER['HTTP_REFERER'])));
+		set_request_var('returnto', basename($_SERVER['HTTP_REFERER']));
 	}
 
 	load_current_session_value('returnto', 'sess_grn_returnto', '');
