@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2020 The Cacti Group                                 |
+ | Copyright (C) 2004-2021 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -63,12 +63,13 @@ $database_hostname = 'localhost';
 $database_username = 'cactiuser';
 $database_password = 'cactiuser';
 $database_port     = '3306';
-$database_retries  = 5;
+$database_retries  = 2;
 
 $database_ssl      = false;
 $database_ssl_key  = '';
 $database_ssl_cert = '';
 $database_ssl_ca   = '';
+$database_persist  = true;
 
 /* Default session name - Session name must contain alpha characters */
 $cacti_session_name = 'Cacti';
@@ -108,7 +109,7 @@ $db_var_defaults = array(
 	'database_username' => NULL,
 	'database_password' => NULL,
 	'database_port'     => '3306',
-	'database_retries'  => 5,
+	'database_retries'  => 2,
 	'database_ssl'      => false,
 	'database_ssl_key'  => '',
 	'database_ssl_cert' => '',
@@ -257,6 +258,9 @@ if (isset($input_whitelist)) {
 include_once($config['library_path'] . '/database.php');
 include_once($config['library_path'] . '/functions.php');
 include_once($config['include_path'] . '/global_constants.php');
+include_once($config['library_path'] . '/html.php');
+include_once($config['library_path'] . '/html_utility.php');
+include_once($config['library_path'] . '/html_validate.php');
 
 $filename = get_current_page();
 
@@ -273,11 +277,21 @@ $config['connection'] = 'online';
 if ($config['poller_id'] > 1 || isset($rdatabase_hostname)) {
 	$local_db_cnn_id = db_connect_real($database_hostname, $database_username, $database_password, $database_default, $database_type, $database_port, $database_retries, $database_ssl, $database_ssl_key, $database_ssl_cert, $database_ssl_ca);
 
-	if (!isset($rdatabase_retries)) $rdatabase_retries = 5;
-	if (!isset($rdatabase_ssl)) $rdatabase_ssl = false;
-	if (!isset($rdatabase_ssl_key)) $rdatabase_ssl_key = false;
+	if (!isset($rdatabase_retries))  $rdatabase_retries  = 2;
+	if (!isset($rdatabase_ssl))      $rdatabase_ssl      = false;
+	if (!isset($rdatabase_ssl_key))  $rdatabase_ssl_key  = false;
 	if (!isset($rdatabase_ssl_cert)) $rdatabase_ssl_cert = false;
-	if (!isset($rdatabase_ssl_ca)) $rdatabase_ssl_ca = false;
+	if (!isset($rdatabase_ssl_ca))   $rdatabase_ssl_ca   = false;
+
+	// Check for recovery
+	if (is_object($local_db_cnn_id)) {
+		$boost_records = db_fetch_cell('SELECT COUNT(*)
+			FROM poller_output_boost', '', true, $local_db_cnn_id);
+
+		if ($boost_records > 0) {
+			$config['connection'] = 'recovery';
+		}
+	}
 
 	/* gather the existing cactidb version */
 	$config['cacti_db_version'] = db_fetch_cell('SELECT cacti FROM version LIMIT 1', false, $local_db_cnn_id);
@@ -285,7 +299,7 @@ if ($config['poller_id'] > 1 || isset($rdatabase_hostname)) {
 	// We are a remote poller also try to connect to the remote database
 	$remote_db_cnn_id = db_connect_real($rdatabase_hostname, $rdatabase_username, $rdatabase_password, $rdatabase_default, $rdatabase_type, $rdatabase_port, $database_retries, $rdatabase_ssl, $rdatabase_ssl_key, $rdatabase_ssl_cert, $rdatabase_ssl_ca);
 
-	if ($config['is_web'] && $remote_db_cnn_id &&
+	if ($config['is_web'] && is_object($remote_db_cnn_id) &&
 		$config['connection'] != 'recovery' &&
 		$config['cacti_db_version'] != 'new_install') {
 
@@ -299,18 +313,18 @@ if ($config['poller_id'] > 1 || isset($rdatabase_hostname)) {
 		$database_ssl_key   = $rdatabase_ssl_key;
 		$database_ssl_cert  = $rdatabase_ssl_cert;
 		$database_ssl_ca    = $rdatabase_ssl_ca;
-	}
-
-	if ($remote_db_cnn_id && $config['connection'] != 'recovery' && $config['cacti_db_version'] != 'new_install') {
-		$config['connection'] = 'online';
+	} elseif (is_object($remote_db_cnn_id)) {
+		if ($config['connection'] != 'recovery') {
+			$config['connection'] = 'online';
+		}
 	} else {
 		$config['connection'] = 'offline';
 	}
 } else {
-	if (!isset($database_ssl)) $database_ssl = false;
-	if (!isset($database_ssl_key)) $database_ssl_key = false;
+	if (!isset($database_ssl))      $database_ssl      = false;
+	if (!isset($database_ssl_key))  $database_ssl_key  = false;
 	if (!isset($database_ssl_cert)) $database_ssl_cert = false;
-	if (!isset($database_ssl_ca)) $database_ssl_ca = false;
+	if (!isset($database_ssl_ca))   $database_ssl_ca   = false;
 
 	if (!db_connect_real($database_hostname, $database_username, $database_password, $database_default, $database_type, $database_port, $database_retries, $database_ssl, $database_ssl_key, $database_ssl_cert, $database_ssl_ca)) {
 		$ps = $config['is_web'] ? '<p>' : '';
@@ -355,15 +369,6 @@ if ($config['poller_id'] > 1) {
 	}
 }
 
-if ($config['poller_id'] > 1 && $config['connection'] == 'online') {
-	$boost_records = db_fetch_cell('SELECT COUNT(*)
-		FROM poller_output_boost', '', true, $local_db_cnn_id);
-
-	if ($boost_records > 0) {
-		$config['connection'] = 'recovery';
-	}
-}
-
 if (isset($cacti_db_session) && $cacti_db_session && db_table_exists('sessions')) {
 	include(dirname(__FILE__) . '/session.php');
 } else {
@@ -425,11 +430,14 @@ if ($config['is_web']) {
 
 	/* increased web hardening */
 	$script_policy = read_config_option('content_security_policy_script');
-	if ($script_policy != '0' && $script_policy != '') {
+	if ($script_policy == 'unsafe-eval') {
 		$script_policy = "'$script_policy'";
+	} else {
+		$script_policy = '';
 	}
+	$alternates = html_escape(read_config_option('content_security_alternate_sources'));
 
-	header("Content-Security-Policy: default-src *; img-src 'self' data: blob:; style-src 'self' 'unsafe-inline'; script-src 'self' $script_policy 'unsafe-inline'; frame-ancestors 'self'; worker-src 'self'");
+	header("Content-Security-Policy: default-src *; img-src 'self' $alternates data: blob:; style-src 'self' 'unsafe-inline' $alternates; script-src 'self' $script_policy 'unsafe-inline' $alternates; frame-ancestors 'self'; worker-src 'self'");
 
 	/* prevent IE from silently rejects cookies sent from third party sites. */
 	header('P3P: CP="CAO PSA OUR"');
@@ -465,6 +473,11 @@ if ($config['is_web']) {
 			cacti_session_destroy();
 		}
 	}
+
+	/* Sanitize the http referer */
+	if (isset($_SERVER['HTTP_REFERER'])) {
+		$_SERVER['HTTP_REFERER'] = sanitize_uri($_SERVER['HTTP_REFERER']);
+	}
 }
 
 /* emulate 'register_globals' = 'off' if turned on */
@@ -498,12 +511,9 @@ include_once($config['include_path'] . '/global_languages.php');
 include_once($config['library_path'] . '/auth.php');
 include_once($config['library_path'] . '/plugins.php');
 include_once($config['include_path'] . '/plugins.php');
-include_once($config['library_path'] . '/html_validate.php');
-include_once($config['library_path'] . '/html_utility.php');
 include_once($config['include_path'] . '/global_arrays.php');
 include_once($config['include_path'] . '/global_settings.php');
 include_once($config['include_path'] . '/global_form.php');
-include_once($config['library_path'] . '/html.php');
 include_once($config['library_path'] . '/html_form.php');
 include_once($config['library_path'] . '/html_filter.php');
 include_once($config['library_path'] . '/variables.php');
@@ -536,6 +546,14 @@ if ($config['is_web']) {
 			}
 		}
 	}
+
+	if (isset($_COOKIE['CactiTimeZone'])) {
+		$minutes = $_COOKIE['CactiTimeZone'];
+		$hours   = $minutes / 60;
+
+		putenv('TZ=GMT' . ($hours > 0 ? '-':'+') . abs($hours));
+		ini_set('date.timezone', 'Etc/GMT' . ($hours > 0 ? '-':'+') . abs($hours));
+	}
 }
 
 api_plugin_hook('config_insert');
