@@ -1,6 +1,6 @@
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2020 The Cacti Group                                 |
+ | Copyright (C) 2004-2021 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -37,7 +37,6 @@
 		var clientTime = new Date();
 		var clientTimeOffset = clientTime.getTimezoneOffset()*60*(-1);			//requires -1, because PHP return the opposite
 		var timeOffset = 0;
-		var activeElement = '';
 		var mouseDown = false;
 
 		// default values of the different options being offered
@@ -66,7 +65,7 @@
 			// 'options' contains the start input parameters
 			options: $.extend(defaults, options),
 			// 'attributes' holds all values that will describe the selected area
-			attr: { activeElement:'', start:'none', end:'none', action:'left2right', location: window.location.href.split('?'), urlPath: ((typeof urlPath == 'undefined') ? '' : urlPath), origin: ((typeof location.origin == 'undefined') ? location.protocol + '//' + location.host : location.origin)}
+			attr: { start:'none', end:'none', action:'left2right', location: window.location.href.split('?'), urlPath: ((typeof urlPath == 'undefined') ? '' : urlPath), origin: ((typeof location.origin == 'undefined') ? location.protocol + '//' + location.host : location.origin)}
 		};
 
 		// support jQuery's concatenation
@@ -149,16 +148,15 @@
 		/* init zoom */
 		function zoom_init(image) {
 			var $this = image;
-
-			if ($('#zoom-container').hasClass('zoom_active_' + zoomGetImageId($this))) {
-			    zoomElements_remove();
-				zoomFunction_init($this);
-			}
+			var activeElement = '';
 
 			$this.parent().disableSelection();
 			$this.off().mouseover(
 				function(){
-					if (!mouseDown && !zoom.marker[1].placed) {
+					if($('#zoom-container').length != 0) {
+						activeElement = $('#zoom-container').attr('data-active-element');
+					}
+					if (!activeElement || activeElement !== zoomGetImageId($this)){
 						zoomElements_remove();
 						zoomFunction_init($this);
 					}
@@ -255,12 +253,14 @@
 			// and reposition these elements.
 
 			// add the container for all elements Zoom requires
-			if ($('#zoom-container').length == 0) {
+			if ($('#zoom-container').length === 0) {
 				// Please note: IE does not fire hover or click behaviors on completely transparent elements.
 				// Use a background color and set opacity to 1% as a workaround.(see CSS file)
-				$('<div id="zoom-container"></div>').appendTo('body').delay(1000);
-				$('#zoom-container').css({ position: 'absolute', 'pointer-events': 'none' }).removeClass().addClass('zoom_active_' + zoomGetId(zoom));
-			}
+				$('<div id="zoom-container" data-active-element=""></div>').appendTo('body').delay(1000);
+				$('#zoom-container').css({ position: 'absolute', 'pointer-events': 'none' });
+			}else {
+                $('#zoom-container').attr('data-active-element', '');
+            }
 
 			// add a hidden anchor to use for downloads
 			if ($('#zoom-image').length == 0) {
@@ -440,7 +440,8 @@
 		* registers all the different mouse click event handler
 		*/
 		function zoomAction_init(image) {
-			if (zoom.custom.zoomMode == 'quick') {
+
+			if (zoom.custom.zoomMode === 'quick') {
 				zoom.box.width = zoom.graph.width;
 				$('#zoom-box').css({ width:zoom.box.width + 'px' });
 				$('#zoom-area').resizable({ containment: '#zoom-box', handles: 'e, w' });
@@ -448,6 +449,9 @@
 					switch(e.which) {
 						/* clicking the left mouse button will initiates a zoom-in */
 						case 1:
+							// remember active element
+							$('#zoom-container').attr('data-active-element', zoomGetImageId(image));
+							// ensure menu is closed
 							zoomContextMenu_hide();
 							// reset the zoom area
 							zoom.attr.start = e.pageX;
@@ -509,7 +513,9 @@
 				$('#zoom-box').off('mousedown').on('mousedown', function(e) {
 					switch(e.which) {
 						case 1:
-							/* hide context menu if open */
+							// remember active element
+							$('#zoom-container').attr('data-active-element', zoomGetImageId(image));
+							// ensure menu is closed
 							zoomContextMenu_hide();
 
 							/* find out which marker has to be added */
@@ -732,7 +738,7 @@
 						graph_start = newGraphStartTime;
 						graph_end = newGraphEndTime;
 
-						initializeGraphs();
+						initializeGraphs(true);
 					}else{
 						$('#graph_start').val(newGraphStartTime);
 						$('#graph_end').val(newGraphEndTime);
@@ -748,7 +754,7 @@
 				return false;
 			} else {
 				/* graph view is already in zoom status */
-				open(zoom.attr.location[0] + '?action=' + zoom.graph.action + '&local_graph_id=' + zoom.graph.local_graph_id + '&rra_id=' + zoom.graph.rra_id + '&view_type=' + zoom.graph.view_type + '&graph_start=' + newGraphStartTime + '&graph_end=' + newGraphEndTime + '&graph_height=' + zoom.graph.height + '&graph_width=' + zoom.graph.width + '&title_font_size=' + zoom.graph.title_font_size, '_self');
+				open(zoom.attr.location[0] + '?action=' + zoom.graph.action + '&local_graph_id=' + zoom.graph.local_graph_id + '&rra_id=' + zoom.graph.rra_id + '&view_type=' + zoom.graph.view_type + '&graph_start=' + newGraphStartTime + '&graph_end=' + newGraphEndTime + '&graph_height=' + zoom.graph.height + '&graph_width=' + zoom.graph.width + '&title_font_size=' + zoom.graph.title_font_size + '&disable_cache=true', '_self');
 			}
 
 			zoom.attr.start = 'none';
@@ -858,7 +864,7 @@
 						graph_start = newGraphStartTime;
 						graph_end = newGraphEndTime;
 
-						initializeGraphs();
+						initializeGraphs(true);
 					}else{
 						$('#graph_start').val(newGraphStartTime);
 						$('#graph_end').val(newGraphEndTime);
@@ -871,7 +877,7 @@
 
 				zoomAction_update_session(newGraphStartTime, newGraphEndTime);
 			} else {
-				open(zoom.attr.location[0] + '?action=' + zoom.graph.action + '&local_graph_id=' + zoom.graph.local_graph_id + '&rra_id=' + zoom.graph.rra_id + '&view_type=' + zoom.graph.view_type + '&graph_start=' + newGraphStartTime + '&graph_end=' + newGraphEndTime + '&graph_height=' + zoom.graph.height + '&graph_width=' + zoom.graph.width + '&title_font_size=' + zoom.graph.title_font_size, '_self');
+				open(zoom.attr.location[0] + '?action=' + zoom.graph.action + '&local_graph_id=' + zoom.graph.local_graph_id + '&rra_id=' + zoom.graph.rra_id + '&view_type=' + zoom.graph.view_type + '&graph_start=' + newGraphStartTime + '&graph_end=' + newGraphEndTime + '&graph_height=' + zoom.graph.height + '&graph_width=' + zoom.graph.width + '&title_font_size=' + zoom.graph.title_font_size + '&disable_cache=true', '_self');
 			}
 		}
 
@@ -1002,7 +1008,7 @@
 							zoom.custom.zoomMode			= 'advanced';
 							storage.set(zoom.options.cookieName, serialize(zoom.custom));
 						}
-
+						zoomContextMenu_hide();
 						zoomElements_reset();
 						zoomAction_init(zoom.initiator);
 
@@ -1107,12 +1113,12 @@
 					if (zoom.image.rra_id > 0) {
 						url += '&rra_id='+zoom.image.rra_id;
 					}
-					url += '&graph_start=' + zoom.graph.start + '&graph_end=' + zoom.graph.end + '&graph_width=' + zoom.graph.width + '&graph_height=' + zoom.graph.height + ( (zoom.image.legend === true) ? '' : '&graph_nolegend=true' );
+					url += '&graph_start=' + zoom.graph.start + '&graph_end=' + zoom.graph.end + '&graph_width=' + zoom.graph.width + '&graph_height=' + zoom.graph.height + ( (zoom.image.legend === true) ? '' : '&graph_nolegend=true' ) + '&disable_cache=true';
 					$('#zoom-image').removeAttr('download').attr({ 'href':url, 'target': '_bank' }).get(0).click();
 
 					break;
 				case 'link':
-					var url = zoom.attr.origin + ((zoom.attr.urlPath == '') ? '/' : zoom.attr.urlPath) + 'graph_image.php?local_graph_id=' + zoom.image.id + '&graph_start=' + zoom.graph.start + '&graph_end=' + zoom.graph.end + '&graph_width=' + zoom.graph.width + '&graph_height=' + zoom.graph.height + ( (zoom.image.legend === true) ? '' : '&graph_nolegend=true' );
+					var url = zoom.attr.origin + ((zoom.attr.urlPath == '') ? '/' : zoom.attr.urlPath) + 'graph_image.php?local_graph_id=' + zoom.image.id + '&graph_start=' + zoom.graph.start + '&graph_end=' + zoom.graph.end + '&graph_width=' + zoom.graph.width + '&graph_height=' + zoom.graph.height + ( (zoom.image.legend === true) ? '' : '&graph_nolegend=true' ) + '&disable_cache=true';
 					$('#zoom-textarea').html(url).select();
 					try {
 						var successful = document.execCommand('copy');
