@@ -44,7 +44,7 @@ function themeReady() {
 	setImportFile(noFileSelected);
 
 	function setImportFile(fileText) {
-		$('.import_text').html(fileText);
+		$('.import_text').text(fileText);
 	}
 
 	maxWidth = 480;
@@ -120,7 +120,7 @@ function themeReady() {
 		hostOpen = false;
 		clearTimeout(hostTimer);
 		clearTimeout(clickTimeout);
-		$('#host').autocomplete('close');
+		$('#host').autocomplete('close').select();
 	}).click(function() {
 		if (hostOpen) {
 			$('#host').autocomplete('close');
@@ -133,6 +133,7 @@ function themeReady() {
 				hostOpen = true;
 			}, 200);
 		}
+		$('#host').select();
 	}).on('mouseenter', function() {
 		$(this).addClass('ui-state-hover');
 		$('input#host').addClass('ui-state-hover');
