@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2021 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -29,11 +29,12 @@ $using_guest_account = false;
 
 if (!isset_request_var('headercontent')) {?>
 <!DOCTYPE html>
-<html>
+<html lang='<?php print CACTI_LOCALE;?>'>
 <head>
 	<?php html_common_header($page_title);?>
 </head>
 <body>
+	<a class='skip-link' href='#main' style='display:none'>Skip to main</a>
 	<div id='cactiPageHead' class='cactiPageHead' role='banner'>
 		<div id='tabs'><?php html_show_tabs_left();?></div>
 		<div class='cactiGraphHeaderBackground' style='display:none'><div id='gtabs'><?php print html_graph_tabs_right();?></div></div>
@@ -61,4 +62,4 @@ if (!isset_request_var('headercontent')) {?>
 			</table>
 		</div>
 		<div id='navigation_right' class='cactiConsoleContentArea'>
-			<div style='position:relative;display:none;' id='main'>
+			<main style='position:relative;display:none;' id='main'>
