@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2020 The Cacti Group                                 |
+ | Copyright (C) 2004-2021 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -22,6 +22,21 @@
  +-------------------------------------------------------------------------+
 */
 
-function upgrade_to_1_2_7() {
-	db_install_add_key('data_input_data', 'index', 'data_template_data_id', array('data_template_data_id'));
+function upgrade_to_1_2_11() {
+	db_install_execute("CREATE TABLE IF NOT EXISTS `processes` (
+		`id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
+		`pid` int(10) unsigned NOT NULL DEFAULT 0,
+		`tasktype` varchar(20) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
+		`taskname` varchar(40) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
+		`taskid` int(10) unsigned NOT NULL DEFAULT 0,
+		`timeout` int(11) DEFAULT 300,
+		`started` timestamp NOT NULL DEFAULT current_timestamp(),
+		`last_update` timestamp NOT NULL DEFAULT '0000-00-00 00:00:00',
+		PRIMARY KEY (`pid`,`tasktype`,`taskname`,`taskid`),
+		KEY `tasktype` (`tasktype`),
+		KEY `pid` (`pid`),
+		KEY `id` (`id`))
+		ENGINE=MEMORY
+		COMMENT='Stores Process Status for Cacti Background Processes'");
 }
+
