@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2020 The Cacti Group                                 |
+ | Copyright (C) 2004-2021 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -80,12 +80,12 @@ function run_data_query($host_id, $snmp_query_id, $automation = false, $force =
 		return false;
 	}
 
-	query_debug_timer_start();
-
 	include_once($config['library_path'] . '/poller.php');
 	include_once($config['library_path'] . '/api_data_source.php');
 	include_once($config['library_path'] . '/utility.php');
 
+	query_debug_timer_start();
+
 	// Load the XML structure for custom settings detection
 	$query_array = get_data_query_array($snmp_query_id);
 
@@ -360,7 +360,7 @@ function run_data_query($host_id, $snmp_query_id, $automation = false, $force =
 
 	/* update the auto reindex cache */
 	if (cacti_sizeof($changed_ids)) {
-		query_debug_timer_offset('data_query', __('Update Re-Index Cache complete. There were ' . sizeof($changed_ids) . ' index changes, and ' . sizeof($orphaned_ids) . ' orphaned indexes.'));
+		query_debug_timer_offset('data_query', __('Update Re-Index Cache complete. There were ' . cacti_sizeof($changed_ids) . ' index changes, and ' . cacti_sizeof($orphaned_ids) . ' orphaned indexes.'));
 
 		/* update the poller cache */
 		update_poller_cache_from_query($host_id, $snmp_query_id, $changed_ids);
@@ -439,7 +439,7 @@ function data_query_remove_disabled_items($orphaned_ids) {
 		if (cacti_sizeof($archive_tables)) {
 			foreach($archive_tables as $table) {
 				db_execute_prepared("DELETE FROM $table
-					WHERE local_data_id IN (' . implode(', ', $orphaned_ids) . ')", false);
+					WHERE local_data_id IN (" . implode(', ', $orphaned_ids) . ')', false);
 			}
 		}
 	}
@@ -625,7 +625,7 @@ function query_script_host($host_id, $snmp_query_id) {
 		$script_num_index_array = exec_into_array($script_path);
 
 		// if the number of indexes does not exist use emulation
-		if (!sizeof($script_num_index_array)) {
+		if (!cacti_sizeof($script_num_index_array)) {
 			query_debug_timer_offset('data_query', __('Data Query returned no indexes.'));
 			query_debug_timer_offset('data_query', __('&lt;arg_num_indexes&gt; exists in XML file but no data returned., \'Index Count Changed\' not supported'));
 		}
@@ -649,7 +649,7 @@ function query_script_host($host_id, $snmp_query_id) {
 	/* fetch specified index */
 	$script_index_array = exec_into_array($script_path);
 
-	if (!sizeof($script_index_array)) {
+	if (!cacti_sizeof($script_index_array)) {
 		query_debug_timer_offset('data_query', __('ERROR: Data Query returned no indexes.'));
 		return false;
 	}
@@ -758,7 +758,7 @@ function query_snmp_host($host_id, $snmp_query_id) {
 	$host = db_fetch_row_prepared('SELECT hostname, snmp_community, snmp_version,
 		snmp_username, snmp_password, snmp_auth_protocol, snmp_priv_passphrase,
 		snmp_priv_protocol, snmp_context, snmp_engine_id, snmp_port, snmp_timeout,
-		ping_retries, max_oids
+		ping_retries, max_oids, bulk_walk_size
 		FROM host
 		WHERE id = ?',
 		array($host_id));
@@ -788,16 +788,73 @@ function query_snmp_host($host_id, $snmp_query_id) {
 		return false;
 	}
 
-	$session = cacti_snmp_session($host['hostname'], $host['snmp_community'],
-		$host['snmp_version'], $host['snmp_username'], $host['snmp_password'],
-		$host['snmp_auth_protocol'], $host['snmp_priv_passphrase'], $host['snmp_priv_protocol'],
-		$host['snmp_context'], $host['snmp_engine_id'],  $host['snmp_port'],
-		$host['snmp_timeout'], $host['ping_retries'], $host['max_oids']);
+	if ($host['bulk_walk_size'] <= 0) {
+		$walk_sizes = array(1, 5, 10, 15, 20, 25, 30, 40, 50, 60);
+		$low_total  = 999;
+		$selected   = -1;
 
-	if ($session === false) {
-		debug_log_insert('data_query', __('Failed to load SNMP session.'));
+		query_debug_timer_offset('data_query', __('Auto Bulk Walk Size Selected.'));
 
-		return false;
+		foreach($walk_sizes as $size) {
+			$session = cacti_snmp_session($host['hostname'], $host['snmp_community'],
+				$host['snmp_version'], $host['snmp_username'], $host['snmp_password'],
+				$host['snmp_auth_protocol'], $host['snmp_priv_passphrase'], $host['snmp_priv_protocol'],
+				$host['snmp_context'], $host['snmp_engine_id'],  $host['snmp_port'],
+				$host['snmp_timeout'], $host['ping_retries'], $host['max_oids'], $size);
+
+			if ($session === false) {
+				debug_log_insert('data_query', __('Failed to load SNMP session.'));
+
+				return false;
+			}
+
+			/* fetch specified index at specified OID, measuring time */
+			$start = microtime(true);
+			$snmp_indexes = cacti_snmp_session_walk($session, $snmp_queries['oid_index']);
+			$end   = microtime(true);
+
+			query_debug_timer_offset('data_query', __('Tested Bulk Walk Size %d with a response of %2.4f.', $size, $end - $start));
+
+			$total = $end - $start;
+			if ($total > $low_total) {
+				break;
+			} else {
+				$walk_size = $size;
+				$low_total = $total;
+			}
+		}
+
+		query_debug_timer_offset('data_query', __('Bulk Walk Size selected was %d.', $walk_size));
+
+		if ($host['bulk_walk_size'] == 0) {
+			query_debug_timer_offset('data_query', __('Saving Bulk Walk Size to Device.'));
+
+			$host['bulk_walk_size'] = $size;
+
+			db_execute_prepared('UPDATE host
+				SET bulk_walk_size = ?
+				WHERE id = ?',
+				array($size, $host_id));
+		}
+	} else {
+		$walk_size = $host['bulk_walk_size'];
+
+		query_debug_timer_offset('data_query', __('Bulk Walk Size is fixed at %d.', $walk_size));
+
+		$session = cacti_snmp_session($host['hostname'], $host['snmp_community'],
+			$host['snmp_version'], $host['snmp_username'], $host['snmp_password'],
+			$host['snmp_auth_protocol'], $host['snmp_priv_passphrase'], $host['snmp_priv_protocol'],
+			$host['snmp_context'], $host['snmp_engine_id'],  $host['snmp_port'],
+			$host['snmp_timeout'], $host['ping_retries'], $host['max_oids'], $walk_size);
+
+		if ($session === false) {
+			debug_log_insert('data_query', __('Failed to load SNMP session.'));
+
+			return false;
+		}
+
+		/* fetch specified index at specified OID */
+		$snmp_indexes = cacti_snmp_session_walk($session, $snmp_queries['oid_index']);
 	}
 
 	/* provide data for oid_num_indexes, if given */
@@ -809,9 +866,6 @@ function query_snmp_host($host_id, $snmp_query_id) {
 		query_debug_timer_offset('data_query', __('&lt;oid_num_indexes&gt; missing in XML file, \'Index Count Changed\' emulated by counting oid_index entries'));
 	}
 
-	/* fetch specified index at specified OID */
-	$snmp_indexes = cacti_snmp_session_walk($session, $snmp_queries['oid_index']);
-
 	query_debug_timer_offset('data_query', __('Executing SNMP walk for list of indexes @ \'%s\' Index Count: %s', $snmp_queries['oid_index'] , cacti_sizeof($snmp_indexes)));
 
 	/* no data found; get out */
@@ -964,7 +1018,7 @@ function query_snmp_host($host_id, $snmp_query_id) {
 						$oids[] = $value['oid'];
 					}
 
-					debug_log_insert('data_query', __('Executing SNMP get for %s oids (%s)' , count($oids), implode(', ', $oids)));
+					debug_log_insert('data_query', __('Executing SNMP get for %s oids (%s)' , cacti_count($oids), implode(', ', $oids)));
 
 					$value_output_format = SNMP_STRING_OUTPUT_GUESS;
 					if (isset($field_array['output_format'])) {
@@ -1994,7 +2048,7 @@ function get_ordered_index_type_list($host_id, $data_query_id) {
 	$return_array = array();
 
 	// Reorder the sort fields by desired order
-	if (sizeof($avail_indexes)) {
+	if (cacti_sizeof($avail_indexes)) {
 		foreach($avail_indexes as $index) {
 			if (array_search($index, $xml_outputs) !== false) {
 				$return_array[] = $index;
@@ -2079,7 +2133,7 @@ function get_best_data_query_index_type($host_id, $data_query_id) {
 	if ($index_type == '') {
 		$raw_xml = get_data_query_array($data_query_id);
 
-		if (sizeof($raw_xml)) {
+		if (cacti_sizeof($raw_xml)) {
 			if (isset($raw_xml['index_order']) && $raw_xml['index_order'] != '') {
 				$order = explode(':', $raw_xml['index_order']);
 
@@ -2090,7 +2144,7 @@ function get_best_data_query_index_type($host_id, $data_query_id) {
 					array($order[0], $host_id, $data_query_id));
 
 				return $order[0];
-			} elseif (isset($raw_xml['fields']) && sizeof($raw_xml['fields'])) {
+			} elseif (isset($raw_xml['fields']) && cacti_sizeof($raw_xml['fields'])) {
 				foreach($raw_xml['fields'] as $key => $attribs) {
 					break;
 				}
@@ -2258,7 +2312,7 @@ function api_data_query_errors($snmp_query_graph_id, $post) {
 
 	$errors = false;
 
-	if (sizeof($data_sources)) {
+	if (cacti_sizeof($data_sources)) {
 		foreach($data_sources as $ds) {
 			if (!isset($post['dsdt_' . $ds['data_template_id'] . '_' . $ds['id'] . '_check'])) {
 				raise_message('mapping_error', __('You must select an XML output column for Data Source \'%s\' and toggle the checkbox to its right', $ds['data_source_name']), MESSAGE_LEVEL_ERROR);
