@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2021 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -37,8 +37,8 @@
    @param $db_ssl_ca - the ssl ca
    @returns - (bool) '1' for success, '0' for error */
 function db_connect_real($device, $user, $pass, $db_name, $db_type = 'mysql', $port = '3306', $retries = 20,
-	$db_ssl = false, $db_ssl_key = '', $db_ssl_cert = '', $db_ssl_ca = '') {
-	global $database_sessions, $database_total_queries, $config;
+	$db_ssl = false, $db_ssl_key = '', $db_ssl_cert = '', $db_ssl_ca = '', $persist = false) {
+	global $database_sessions, $database_total_queries, $database_persist, $config;
 	$database_total_queries = 0;
 
 	$i = 0;
@@ -64,14 +64,21 @@ function db_connect_real($device, $user, $pass, $db_name, $db_type = 'mysql', $p
 			return false;
 		}
 
-		$flags[PDO::ATTR_PERSISTENT] = true;
+		if (isset($database_persist) && $database_persist == true || $persist) {
+			$flags[PDO::ATTR_PERSISTENT] = true;
+		}
+
 		$flags[PDO::MYSQL_ATTR_FOUND_ROWS] = true;
 		if ($db_ssl) {
-			if ($db_ssl_key != '' && $db_ssl_cert != '' && $db_ssl_ca != '') {
-				if (file_exists($db_ssl_key) && file_exists($db_ssl_cert) && file_exists($db_ssl_ca)) {
+			if ($db_ssl_ca != '') {
+				if (file_exists($db_ssl_ca)) {
+					$flags[PDO::MYSQL_ATTR_SSL_CA] = $db_ssl_ca;
+				}
+			}
+			if ($db_ssl_key != '' && $db_ssl_cert != '') {
+				if (file_exists($db_ssl_key) && file_exists($db_ssl_cert)) {
 					$flags[PDO::MYSQL_ATTR_SSL_KEY]  = $db_ssl_key;
 					$flags[PDO::MYSQL_ATTR_SSL_CERT] = $db_ssl_cert;
-					$flags[PDO::MYSQL_ATTR_SSL_CA]   = $db_ssl_ca;
 				}
 			}
 		}
@@ -120,6 +127,17 @@ function db_connect_real($device, $user, $pass, $db_name, $db_type = 'mysql', $p
 					$new_modes[] = $mode;
 				}
 			}
+
+			// Add Required modes
+			$required_modes[] = 'ALLOW_INVALID_DATES';
+			$required_modes[] = 'NO_ENGINE_SUBSTITUTION';
+
+			foreach($required_modes as $mode) {
+				if (array_search($mode, $new_modes) === false) {
+					$new_modes[] = $mode;
+				}
+			}
+
 			$sql_mode = implode(',', $new_modes);
 
 			db_execute_prepared('SET SESSION sql_mode = ?', array($sql_mode), false);
@@ -147,6 +165,14 @@ function db_connect_real($device, $user, $pass, $db_name, $db_type = 'mysql', $p
 			}
 			return $cnn_id;
 		} catch (PDOException $e) {
+			if (!isset($config['DATABASE_ERROR'])) {
+				$config['DATABASE_ERROR'] = array();
+			}
+
+			$config['DATABASE_ERROR'][] = array(
+				'Code' => $e->getCode(),
+				'Error' => $e->getMessage(),
+			);
 			// Must catch this exception or else PDO will display an error with our username/password
 			//print $e->getMessage();
 			//exit;
@@ -163,6 +189,27 @@ function db_warning_handler($errno, $errstr, $errfile, $errline, $errcontext) {
 	throw new Exception($errstr, $errno);
 }
 
+function db_binlog_enabled() {
+	$enabled = db_fetch_row('SHOW GLOBAL VARIABLES LIKE "log_bin"');
+
+	if (cacti_sizeof($enabled)) {
+		if (strtolower($enabled['Value']) == 'on' || $enabled['Value'] == 1) {
+			return true;
+		}
+	}
+
+	return false;
+}
+
+function db_get_active_replicas() {
+	return array_rekey(
+		db_fetch_assoc("SELECT SUBSTRING_INDEX(HOST, ':', 1) AS host
+			FROM information_schema.processlist
+			WHERE command = 'Binlog Dump'"),
+		'host', 'host'
+	);
+}
+
 /* db_close - closes the open connection
    @returns - the result of the close command */
 function db_close($db_conn = false) {
@@ -205,7 +252,9 @@ function db_execute_prepared($sql, $params = array(), $log = true, $db_conn = fa
 
 	/* check for a connection being passed, if not use legacy behavior */
 	if (!is_object($db_conn)) {
-		$db_conn = $database_sessions["$database_hostname:$database_port:$database_default"];
+		if (isset($database_sessions["$database_hostname:$database_port:$database_default"])) {
+			$db_conn = $database_sessions["$database_hostname:$database_port:$database_default"];
+		}
 
 		if (!is_object($db_conn)) {
 			$database_last_error = 'DB ' . $execute_name . ' -- No connection found';
@@ -418,7 +467,7 @@ function db_fetch_row_prepared($sql, $params = array(), $log = true, $db_conn =
 	global $config;
 
 	if (!empty($config['DEBUG_SQL_FLOW'])) {
-		db_echo_sql('db_fetch_row_prepared(\'' . clean_up_lines($sql) . '\', $params = (\'' . implode($params, '\', \'') . '\'), $log = ' . $log . ', $db_conn = ' . ($db_conn ? 'true' : 'false') .')' . "\n");
+		db_echo_sql('db_fetch_row_prepared(\'' . clean_up_lines($sql) . '\', $params = (\'' . implode('\', \'', $params) . '\'), $log = ' . $log . ', $db_conn = ' . ($db_conn ? 'true' : 'false') .')' . "\n");
 	}
 
 	return db_execute_prepared($sql, $params, $log, $db_conn, 'Row', false, 'db_fetch_row_return');
@@ -732,11 +781,23 @@ function db_index_matches($table, $index, $columns, $log = true, $db_conn = fals
    @param $log - whether to log error messages, defaults to true
    @returns - (bool) the output of the sql query as a single variable */
 function db_table_exists($table, $log = true, $db_conn = false) {
+	static $results;
+
+	if (isset($results[$table]) && !defined('IN_CACTI_INSTALL') && !defined('IN_PLUGIN_INSTALL')) {
+		return $results[$table];
+	}
+
+	// Separate the database from the table and remove backticks
 	preg_match("/([`]{0,1}(?<database>[\w_]+)[`]{0,1}\.){0,1}[`]{0,1}(?<table>[\w_]+)[`]{0,1}/", $table, $matches);
+
 	if ($matches !== false && array_key_exists('table', $matches)) {
 		$sql = 'SHOW TABLES LIKE \'' . $matches['table'] . '\'';
-		return (db_fetch_cell($sql, '', $log, $db_conn) ? true : false);
+
+		$results[$table] = (db_fetch_cell($sql, '', $log, $db_conn) ? true : false);
+
+		return $results[$table];
 	}
+
 	return false;
 }
 
@@ -782,7 +843,15 @@ function db_cacti_initialized($is_web = true) {
    @param $log - whether to log error messages, defaults to true
    @returns - (bool) the output of the sql query as a single variable */
 function db_column_exists($table, $column, $log = true, $db_conn = false) {
-	return (db_fetch_cell("SHOW columns FROM `$table` LIKE '$column'", '', $log, $db_conn) ? true : false);
+	static $results = array();
+
+	if (isset($results[$table][$column]) && !defined('IN_CACTI_INSTALL') && !defined('IN_PLUGIN_INSTALL')) {
+		return $results[$table][$column];
+	}
+
+	$results[$table][$column] = (db_fetch_cell("SHOW columns FROM `$table` LIKE '$column'", '', $log, $db_conn) ? true : false);
+
+	return $results[$table][$column];
 }
 
 /* db_get_table_column_types - returns all the types for each column of a table
@@ -986,15 +1055,16 @@ function db_update_table($table, $data, $removecolumns = false, $log = true, $db
 	}
 
 	if (isset($data['row_format']) && db_get_global_variable('innodb_file_format', $db_conn) == 'Barracuda') {
-		db_execute("ALTER TABLE `$table` ROW_FORMAT=" . $data['row_format'], $log, $db_conn);
+		db_execute("ALTER TABLE `$table` ROW_FORMAT = " . $data['row_format'], $log, $db_conn);
 	}
 
-	$charset= '';
 	if (isset($data['charset'])) {
-		$charset = ' DEFAULT CHARSET=' . $data['charset'];
+		$charset .= ' DEFAULT CHARSET = ' . $data['charset'];
+		db_execute("ALTER TABLE `$table` " . $charset, $log, $db_conn);
 	}
 
-	if ($charset != '') {
+	if (isset($data['collate'])) {
+		$charset = ' COLLATE = ' . $data['collate'];
 		db_execute("ALTER TABLE `$table` " . $charset, $log, $db_conn);
 	}
 
@@ -1117,15 +1187,23 @@ function db_table_create($table, $data, $log = true, $db_conn = false) {
 			$sql .= " COMMENT = '" . $data['comment'] . "'";
 		}
 
-		if (isset($data['charset'])) {
-			$sql .= ' DEFAULT CHARSET=' . $data['charset'];
-		}
-
 		if (isset($data['row_format']) && db_get_global_variable('innodb_file_format', $db_conn) == 'Barracuda') {
-			$sql .= ' ROW_FORMAT=' . $data['row_format'];
+			$sql .= ' ROW_FORMAT = ' . $data['row_format'];
 		}
 
-		return db_execute($sql, $log, $db_conn);
+		if (db_execute($sql, $log, $db_conn)) {
+			if (isset($data['charset'])) {
+				db_execute("ALLTER TABLE `$table` CHARSET = " . $data['charset']);
+			}
+
+			if (isset($data['collate'])) {
+				db_execute("ALTER TABLE `$table` COLLATE = " . $data['collate']);
+			}
+
+			return true;
+		} else {
+			return false;
+		}
 	}
 }
 
@@ -1541,3 +1619,66 @@ function db_force_remote_cnn() {
 	$database_ssl_ca    = $rdatabase_ssl_ca;
 }
 
+/* db_dump_data - dump data into a file by mysqldump, minimize password be caught.
+   @param $database - default $database_default
+   @param $tables - default all tables
+   @param $credentials - array($name => value, ...) for user, password, host, port, ssl ...
+   @param $output_file - dump file name, default /tmp/cacti.dump.sql
+   @param $options - option strings for mysqldump, if --defaults-extra-file set, dump the data directly
+   @returns - returnl status of the executed command */
+function db_dump_data($database = '', $tables = '', $credentials = array(), $output_file = false, $options = '--extended-insert=FALSE') {
+	global $database_default, $database_username, $database_password;
+	$credentials_string = '';
+
+	if ($database == '') {
+		$database = $database_default;
+	}
+	if (cacti_sizeof($credentials)) {
+		foreach ($credentials as $key => $value) {
+			$name = trim($key);
+			if (strstr($name, '--') !== false) {      //name like --host
+				if($name == '--password') {
+					$password = $value;
+				} else if ($name == '--user') {
+					$username = $value;
+				} else {
+					$credentials_string .= $name . '=' . $value . ' ';
+				}
+			} else if(strstr($name, '-') !== false) { //name like -h
+				if($name == '-p') {
+					$password = $value;
+				} else if ($name == '-u') {
+					$username = $value;
+				} else {
+					$credentials_string .= $name . $value . ' ';
+				}
+			} else {                                  //name like host
+				if($name == 'password') {
+					$password = $value;
+				} else if ($name == 'user') {
+					$username = $value;
+				} else {
+					$credentials_string .= '--' . $name . '=' . $value . ' ';
+				}
+			}
+		}
+	}
+	if (!isset($password)) {
+		$password = $database_password;
+	}
+	if (!isset($username)) {
+		$username = $database_username;
+	}
+	if (strstr($options, '--defaults-extra-file') !== false) {
+		exec("mysqldump $options $credentials_string $database $tables > " . $output_file, $output, $retval);
+	} else {
+		exec("mysqldump $options $credentials_string " . $database . ' version >/dev/null 2>&1', $output, $retval);
+		if ($retval) {
+			exec("mysqldump $options $credentials_string -u" . $username . ' -p' . $password . ' ' . $database . " $tables > " . $output_file, $output, $retval);
+		} else {
+			exec("mysqldump $options $credentials_string $database $tables > " . $output_file, $output, $retval);
+		}
+	}
+	return $retval;
+}
+
