@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2020 The Cacti Group                                 |
+ | Copyright (C) 2004-2021 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -110,7 +110,13 @@ function rrdtool_function_stats($local_data_ids, $start_seconds, $end_seconds, $
 			foreach ($fetch_array_avg[$ldi]['data_source_names'] as $index => $name) {
 				/* clean up DS items that aren't defined on the graph */
 				if (!in_array($name, $local_data_ids[$ldi])) {
-					unset($fetch_array_avg[$ldi]['data_source_names'][$index], $fetch_array_avg[$ldi]['values'][$index]);
+					if (isset($fetch_array_avg[$ldi]['data_source_names'][$index])) {
+						unset($fetch_array_avg[$ldi]['data_source_names'][$index]);
+					}
+
+					if (isset($fetch_array_avg[$ldi]['values'][$index])) {
+						unset($fetch_array_avg[$ldi]['values'][$index]);
+					}
 				}
 			}
 		}
@@ -129,7 +135,13 @@ function rrdtool_function_stats($local_data_ids, $start_seconds, $end_seconds, $
 			foreach ($fetch_array_max[$ldi]['data_source_names'] as $index => $name) {
 				/* clean up DS items that aren't defined on the graph */
 				if (!in_array($name, $local_data_ids[$ldi])) {
-					unset($fetch_array_max[$ldi]['data_source_names'][$index], $fetch_array_max[$ldi]['values'][$index]);
+					if (isset($fetch_array_max[$ldi]['data_source_names'][$index])) {
+						unset($fetch_array_max[$ldi]['data_source_names'][$index]);
+					}
+
+					if (isset($fetch_array_max[$ldi]['values'][$index])) {
+						unset($fetch_array_max[$ldi]['values'][$index]);
+					}
 				}
 			}
 		}
@@ -426,7 +438,7 @@ function variable_nth_percentile(&$regexp_match_array, &$graph, &$graph_item, &$
 	}
 
 	$gi = array();
-	if (sizeof($graph_items)) {
+	if (cacti_sizeof($graph_items)) {
 		foreach ($graph_items as $item) {
 			if ($item['local_data_id'] > 0 && $item['data_source_name'] != '') {
 				if (!empty($item['data_template_rrd_id']) &&
@@ -449,7 +461,7 @@ function variable_nth_percentile(&$regexp_match_array, &$graph, &$graph_item, &$
 	}
 
 	/* Get the Nth percentile values */
-	if (!sizeof($nth_cache)) {
+	if (!cacti_sizeof($nth_cache)) {
 		switch ($type) {
 			case 'current':
 				// Query data for the individual case
@@ -465,28 +477,28 @@ function variable_nth_percentile(&$regexp_match_array, &$graph, &$graph_item, &$
 				break;
 			case 'total':
 			case 'all_max_current':
-				if (sizeof($local_data_array)) {
+				if (cacti_sizeof($local_data_array)) {
 					$nth_cache = nth_percentile($local_data_array, $graph_start, $graph_end, $percentile);
 				}
 
 				break;
 			case 'total_peak':
 			case 'all_max_peak':
-				if (sizeof($local_data_array)) {
+				if (cacti_sizeof($local_data_array)) {
 					$nth_cache = nth_percentile($local_data_array, $graph_start, $graph_end, $percentile, 0, true);
 				}
 
 				break;
 			case 'aggregate':
 			case 'aggregate_sum':
-				if (sizeof($local_data_array)) {
+				if (cacti_sizeof($local_data_array)) {
 					$nth_cache = nth_percentile($local_data_array, $graph_start, $graph_end, $percentile);
 				}
 
 				break;
 			case 'aggregate_peak':
 			case 'aggregate_max':
-				if (sizeof($local_data_array)) {
+				if (cacti_sizeof($local_data_array)) {
 					$nth_cache = nth_percentile($local_data_array, $graph_start, $graph_end, $percentile, 0, true);
 				}
 
@@ -504,7 +516,7 @@ function variable_nth_percentile(&$regexp_match_array, &$graph, &$graph_item, &$
 						}
 					}
 
-					if (sizeof($local_data_array)) {
+					if (cacti_sizeof($local_data_array)) {
 						$nth_cache = nth_percentile($local_data_array, $graph_start, $graph_end, $percentile);
 					}
 				}
@@ -649,6 +661,7 @@ function variable_bandwidth_summation(&$regexp_match_array, &$graph, &$graph_ite
 			foreach ($graph_items as $graph_element) {
 				if (!empty($graph_element['data_template_rrd_id']) &&
 					!empty($graph_element['local_data_id']) &&
+					isset($summation_cache[$graph_element['local_data_id']][$graph_element['data_source_name']]) &&
 					is_graphable_item($graph_item_types[$graph_element['graph_type_id']])) {
 					$summation += $summation_cache[$graph_element['local_data_id']][$graph_element['data_source_name']];
 				}
