@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2018 The Cacti Group                                 |
+ | Copyright (C) 2004-2021 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -191,12 +191,12 @@ function draw_nontemplated_fields_graph_item($graph_template_id, $local_graph_id
 			}
 
 			if ($locked == 'true') {
-				if (substr_count($form_field_name, 'task_item_id') > 0) {
+				if (strpos($form_field_name, 'task_item_id') !== false) {
 					$form_array[$form_field_name]['method'] = 'value';
 
 					if (isset($current_def_value[$item['column_name']])) {
 						$value = db_fetch_cell_prepared("SELECT
-							CONCAT_WS('',CASE WHEN host.description IS NULL THEN 'No Device - ' ELSE '' END,data_template_data.name_cache,' (',data_template_rrd.data_source_name,')') AS name
+							CONCAT_WS('', CASE WHEN host.description IS NULL THEN 'No Device - ' ELSE '' END, data_template_data.name_cache, ' (', data_template_rrd.data_source_name, ')') AS name
 							FROM (data_template_data,data_template_rrd,data_local)
 							LEFT JOIN host ON (data_local.host_id=host.id)
 							WHERE data_template_rrd.local_data_id=data_local.id
@@ -208,17 +208,19 @@ function draw_nontemplated_fields_graph_item($graph_template_id, $local_graph_id
 					}
 				}
 			} elseif (get_selected_theme() != 'classic') {
-				if (substr_count($form_field_name, 'task_item_id') > 0) {
-					$value = db_fetch_cell_prepared("SELECT
-						CONCAT_WS('',CASE WHEN host.description IS NULL THEN 'No Device - ' ELSE '' END,data_template_data.name_cache,' (',data_template_rrd.data_source_name,')') AS name
-						FROM (data_template_data,data_template_rrd,data_local)
-						LEFT JOIN host ON (data_local.host_id=host.id)
-						WHERE data_template_rrd.local_data_id=data_local.id
-						AND data_template_data.local_data_id=data_local.id
-						AND data_template_rrd.id = ?",
-						array($current_def_value[$item['column_name']]));
+				if (strpos($form_field_name, 'task_item_id') !== false) {
+					if (isset($current_def_value[$item['column_name']])) {
+						$value = db_fetch_cell_prepared("SELECT
+							CONCAT_WS('', CASE WHEN host.description IS NULL THEN 'No Device - ' ELSE '' END, data_template_data.name_cache, ' (', data_template_rrd.data_source_name, ')') AS name
+							FROM (data_template_data,data_template_rrd,data_local)
+							LEFT JOIN host ON (data_local.host_id=host.id)
+							WHERE data_template_rrd.local_data_id=data_local.id
+							AND data_template_data.local_data_id=data_local.id
+							AND data_template_rrd.id = ?",
+							array($current_def_value[$item['column_name']]));
 
-					$form_array[$form_field_name]['value'] = $value;
+						$form_array[$form_field_name]['value'] = $value;
+					}
 				}
 			}
 
@@ -588,31 +590,31 @@ function draw_custom_data_row($field_name, $data_input_field_id, $data_template_
 		WHERE id = ?',
 		array($data_input_field_id));
 
-	if (($field['type_code'] == 'index_type') && (db_fetch_cell_prepared('SELECT local_data_id FROM data_template_data WHERE id = ?', array($data_template_data_id)) > 0)) {
-		$index_type = db_fetch_assoc_prepared('SELECT
-			host_snmp_cache.field_name
-			FROM (data_template_data,data_local,host_snmp_cache)
-			WHERE data_template_data.local_data_id=data_local.id
-			AND data_local.snmp_query_id=host_snmp_cache.snmp_query_id
-			AND data_template_data.id = ?
-			GROUP BY host_snmp_cache.field_name',
-			array($data_template_data_id));
+	$local_data = db_fetch_row_prepared('SELECT dl.*
+		FROM data_template_data AS dtd
+		INNER JOIN data_local AS dl
+		ON dl.id=dtd.local_data_id
+		WHERE dtd.id = ?',
+		array($data_template_data_id));
+
+	if ($field['type_code'] == 'index_type' && cacti_sizeof($local_data)) {
+		$index_type = db_fetch_assoc_prepared('SELECT DISTINCT hsc.field_name
+			FROM host_snmp_cache AS hsc
+			WHERE hsc.host_id = ?
+			AND hsc.snmp_query_id = ?',
+			array($local_data['host_id'], $local_data['snmp_query_id']));
 
 		if (cacti_sizeof($index_type) == 0) {
 			print "<em>" . __('Data Query Data Sources must be created through %s', "<a href='graphs_new.php'>" . __('New Graphs') . ".</a>") . "</em>\n";
 		} else {
 			form_dropdown($field_name, $index_type, 'field_name', 'field_name', $current_value, '', '', '');
 		}
-	} elseif (($field['type_code'] == 'output_type') && (db_fetch_cell_prepared('SELECT local_data_id FROM data_template_data WHERE id = ?', array($data_template_data_id)) > 0)) {
-		$output_type = db_fetch_assoc_prepared('SELECT
-			snmp_query_graph.id,
-			snmp_query_graph.name
-			FROM (data_template_data,data_local,snmp_query_graph)
-			WHERE data_template_data.local_data_id=data_local.id
-			AND data_local.snmp_query_id=snmp_query_graph.snmp_query_id
-			AND data_template_data.id = ?
-			GROUP BY snmp_query_graph.id',
-			array($data_template_data_id));
+	} elseif ($field['type_code'] == 'output_type' && cacti_sizeof($local_data)) {
+		$output_type = db_fetch_assoc_prepared('SELECT id, name
+			FROM snmp_query_graph AS sqg
+			WHERE snmp_query_id = ?
+			ORDER BY name',
+			array($local_data['snmp_query_id']));
 
 		if (cacti_sizeof($output_type) == 0) {
 			print "<em>" . __('Data Query Data Sources must be created through %s', "<a href='graphs_new.php'>" . __('New Graphs') . ".</a>") . "</em>\n";
