@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2021 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -238,8 +238,10 @@ abstract class LdapError {
 	const Disabled              = 99;
 
 	public static function GetErrorDetails($returnError, $ldapConn = null, $ldapError = 0) {
-		$error_num = $returnError;
-		if ($returnError > 0 && $ldapError == 0 && $ldapConn > 0) {
+		$error_num  = $returnError;
+		$error_text = '';
+
+		if ($ldapConn && $ldapError == 0) {
 			$ldapError = ldap_error($ldapConn);
 		}
 
@@ -262,15 +264,15 @@ abstract class LdapError {
 				break;
 
 			case LdapError::ProtocolErrorVersion:
-				$error_text = __('Protocol Error, Unable to set version');
+				$error_text = __('Protocol Error, Unable to set version (%s)', $ldapError);
 				break;
 
 			case LdapError::ProtocolErrorReferral:
-				$error_text = __('Protocol Error, Unable to set referrals option');
+				$error_text = __('Protocol Error, Unable to set referrals option (%s)', $ldapError);
 				break;
 
 			case LdapError::ProtocolErrorTls:
-				$error_text = __('Protocol Error, unable to start TLS communications');
+				$error_text = __('Protocol Error, unable to start TLS communications (%s)', $ldapError);
 				break;
 
 			case LdapError::ProtocolErrorGeneral:
@@ -278,7 +280,7 @@ abstract class LdapError {
 				break;
 
 			case LdapError::ProtocolErrorBind:
-				$error_text = __('Protocol Error, Unable to bind, LDAP result: %s', $ldapError);
+				$error_text = __('Protocol Error, Unable to bind, LDAP result: (%s)', $ldapError);
 				break;
 
 			case LdapError::ConnectionUnavailable:
@@ -290,7 +292,7 @@ abstract class LdapError {
 				break;
 
 			case LdapError::InsufficientAccess:
-				$error_text = __('Insufficient access');
+				$error_text = __('Insufficient Access');
 				break;
 
 			case LdapError::SearchFoundNoGroup:
@@ -322,7 +324,13 @@ abstract class LdapError {
 				break;
 		}
 
-		return array('error_num' => $error_num, 'error_text' => $error_text, 'error_ldap' => $ldapError, 'dn' => '', 'stack' => cacti_debug_backtrace('', false, false));
+		return array(
+			'error_num'  => $error_num,
+			'error_text' => $error_text,
+			'error_ldap' => $ldapError,
+			'dn'         => '',
+			'stack'      => cacti_debug_backtrace('', false, false)
+		);
 	}
 }
 
@@ -372,7 +380,7 @@ class Ldap {
 		/* set an error handler for ldap */
 		set_error_handler(array($this, 'ErrorHandler'));
 
-		session_write_close();
+		cacti_session_close();
 	}
 
 	function RestoreCactiHandler() {
@@ -382,7 +390,7 @@ class Ldap {
 		/* set an error handler for Cacti */
 		set_error_handler('CactiErrorHandler');
 
-		session_start();
+		cacti_session_start();
 	}
 
 	function RecordError($output, $section = 'LDAP') {
@@ -391,30 +399,90 @@ class Ldap {
 		cacti_log($section . ': ' . $output['stack'], false, 'AUTH', POLLER_VERBOSITY_HIGH);
 	}
 
-	function Authenticate() {
-		$output = array();
+	function Connect() {
+		$output    = array();
+		$ldap_conn = null;
 
 		/* function check */
 		if (!function_exists('ldap_connect')) {
-			return LdapError::GetErrorDetails(LdapError::Disabled);
+			return array(
+				'ldap_conn' => $ldap_conn,
+				'output' => LdapError::GetErrorDetails(LdapError::Disabled)
+			);
 		}
 
 		/* validation */
 		if (empty($this->username)) {
-			return LdapError::GetErrorDetails(LdapError::UndefinedUsername);
+			return array(
+				'ldap_conn' => $ldap_conn,
+				'output' => LdapError::GetErrorDetails(LdapError::UndefinedUsername)
+			);
 		}
 
-		$this->dn = str_replace('<username>', $this->username, $this->dn);
+		/**
+		 * NOTE: The next several settings must be made prior to initial LDAP connection
+		 */
 
-		/* Fix encoding of username and password */
-		$this->username = html_entity_decode($this->username, $this->GetMask(), 'UTF-8');
-		$this->password = html_entity_decode($this->password, $this->GetMask(), 'UTF-8');
+		/* Set debug if selective debug is enabled.  This places log data into the apache error_log */
+		if (get_selective_log_level() == POLLER_VERBOSITY_DEBUG) {
+			cacti_log('LDAP: Setting php-ldap into DEBUG mode.  Check your Web Server error_log for details', false, 'AUTH', POLLER_VERBOSITY_HIGH);
+			ldap_set_option(null, LDAP_OPT_DEBUG_LEVEL, 7);
+		}
 
-		/* Determine connection method and create LDAP Object */
-		$this->SetLdapHandler();
+		if (getenv('TLS_CERT') != '' && defined('LDAP_OPT_X_TLS_CERTFILE')) {
+			cacti_log('NOTE: Settings TLS_CERT to ' . getenv('TLS_CERT'), false, 'AUTH', POLLER_VERBOSITY_HIGH);
+			ldap_set_option(null, LDAP_OPT_X_TLS_CERTFILE, getenv('TLS_CERT'));
+		}
+
+		if (getenv('TLS_CACERT') != '' && defined('LDAP_OPT_X_TLS_CACERTFILE')) {
+			cacti_log('NOTE: Settings TLS_CACERT to ' . getenv('TLS_CACERT'), false, 'AUTH', POLLER_VERBOSITY_HIGH);
+			ldap_set_option(null, LDAP_OPT_X_TLS_CACERTFILE, getenv('TLS_CACERT'));
+		}
+
+		if (getenv('TLS_KEY') != '' && defined('LDAP_OPT_X_TLS_KEYFILE')) {
+			cacti_log('NOTE: Settings TLS_KEY to ' . getenv('TLS_KEY'), false, 'AUTH', POLLER_VERBOSITY_HIGH);
+			ldap_set_option(null, LDAP_OPT_X_TLS_KEYFILE, getenv('TLS_KEY'));
+		}
+
+		if (getenv('TLS_CACERTDIR') != '' && defined('LDAP_OPT_X_TLS_CACERTDIR')) {
+			cacti_log('NOTE: Settings TLS_CACERTDIR to ' . getenv('TLS_CACERTDIR'), false, 'AUTH', POLLER_VERBOSITY_HIGH);
+			ldap_set_option(null, LDAP_OPT_X_TLS_CACERTDIR, getenv('TLS_CACERTDIR'));
+		}
+
+		if ($this->encryption >= 1) {
+			$cert = read_config_option('ldap_tls_certificate');
+			if ($cert == '') {
+				$cert = LDAP_OPT_X_TLS_NEVER;
+			}
+
+			// For good measure, we will use both the php function and set the environment
+			switch($cert) {
+				case LDAP_OPT_X_TLS_NEVER:
+					cacti_log('NOTE: Setting TLS Certificate Requirement to \'never\'', false, 'AUTH', POLLER_VERBOSITY_HIGH);
+					putenv('TLS_REQCERT=never');
+					break;
+				case LDAP_OPT_X_TLS_HARD:
+					cacti_log('NOTE: Setting TLS Certificate Requirement to \'hard\'', false, 'AUTH', POLLER_VERBOSITY_HIGH);
+					putenv('TLS_REQCERT=hard');
+					break;
+				case LDAP_OPT_X_TLS_DEMAND:
+					cacti_log('NOTE: Setting TLS Certificate Requirement to \'demand\'', false, 'AUTH', POLLER_VERBOSITY_HIGH);
+					putenv('TLS_REQCERT=demand');
+					break;
+				case LDAP_OPT_X_TLS_ALLOW:
+					cacti_log('NOTE: Setting TLS Certificate Requirement to \'allow\'', false, 'AUTH', POLLER_VERBOSITY_HIGH);
+					putenv('TLS_REQCERT=allow');
+					break;
+				case LDAP_OPT_X_TLS_TRY:
+					cacti_log('NOTE: Setting TLS Certificate Requirement to \'try\'', false, 'AUTH', POLLER_VERBOSITY_HIGH);
+					putenv('TLS_REQCERT=try');
+					break;
+			}
+
+			ldap_set_option(null, LDAP_OPT_X_TLS_REQUIRE_CERT, $cert);
+		}
 
 		if ($this->encryption == '1') {
-			/* This only works with OpenLDAP, I'm pretty sure this will not work with Solaris, Tony */
 			cacti_log('LDAP: Connect using ldaps://' . $this->host . ':' . $this->port_ssl, false, 'AUTH', POLLER_VERBOSITY_HIGH);
 			$ldap_conn = ldap_connect('ldaps://' . $this->host . ':' . $this->port_ssl);
 		} else {
@@ -427,110 +495,146 @@ class Ldap {
 			cacti_log('LDAP: Setting protocol version to ' . $this->version, false, 'AUTH', POLLER_VERBOSITY_MEDIUM);
 
 			if (!ldap_set_option($ldap_conn, LDAP_OPT_PROTOCOL_VERSION, $this->version)) {
-				$output = LdapError::GetErrorDetails(LdapError::ProtocolErrorVersion);
+				$output = LdapError::GetErrorDetails(LdapError::ProtocolErrorVersion, $ldap_conn);
 				Ldap::RecordError($output);
 				ldap_close($ldap_conn);
-				$this->RestoreCactiHandler();
-				return $output;
+
+				return array(
+					'ldap_conn' => $ldap_conn,
+					'output'    => $output
+				);
 			}
 
 			/* set referrals */
 			if ($this->referrals == '0') {
 				if (!ldap_set_option($ldap_conn, LDAP_OPT_REFERRALS, 0)) {
-					$output = LdapError::GetErrorDetails(LdapError::ProtocolErrorReferral);
+					$output = LdapError::GetErrorDetails(LdapError::ProtocolErrorReferral, $ldap_conn);
 					Ldap::RecordError($output);
 					ldap_close($ldap_conn);
-					$this->RestoreCactiHandler();
-					return $output;
+
+					return array(
+						'ldap_conn' => $ldap_conn,
+						'output'    => $output
+					);
 				}
 			}
 
 			/* start TLS if requested */
 			if ($this->encryption == '2') {
 				if (!ldap_start_tls($ldap_conn)) {
-					$output = LdapError::GetErrorDetails(LdapError::ProtocolErrorTls);
+					$output = LdapError::GetErrorDetails(LdapError::ProtocolErrorTls, $ldap_conn);
+					Ldap::RecordError($output);
+					ldap_close($ldap_conn);
+
+					return array(
+						'ldap_conn' => $ldap_conn,
+						'output'    => $output
+					);
+				}
+			}
+		}
+
+		return array('ldap_conn' => $ldap_conn, 'output' => $output);
+	}
+
+	function Authenticate() {
+		$output = array();
+
+		/* Determine connection method and create LDAP Object */
+		$this->SetLdapHandler();
+
+		$connection = $this->Connect();
+
+		if (cacti_sizeof($connection['output'])) {
+			$this->RestoreCactiHandler();
+			return $connection['output'];
+		} elseif ($connection['ldap_conn'] === false) {
+			$this->RestoreCactiHandler();
+			return LdapError::GetErrorDetails(LdapError::MissingLdapObject);
+		}
+
+		$ldap_conn = $connection['ldap_conn'];
+
+		/* Decode username, and remove bad characters */
+		$this->username = html_entity_decode($this->username, $this->GetMask(), 'UTF-8');
+		$this->username = str_replace(array('&', '|', '(', ')', '*', '>', '<', '!', '='), '', $this->username);
+		$this->password = html_entity_decode($this->password, $this->GetMask(), 'UTF-8');
+		$this->dn = str_replace('<username>', $this->username, $this->dn);
+
+		/* Bind to the LDAP directory */
+		cacti_log('LDAP: Binding with "' . $this->dn . '"', false, 'AUTH', POLLER_VERBOSITY_HIGH);
+		$ldap_response = ldap_bind($ldap_conn, $this->dn, $this->password);
+		if ($ldap_response) {
+			if ($this->group_require == 1) {
+				$ldap_group_response = false;
+
+				/* Process group membership if required */
+				if ($this->group_member_type == 1) {
+					$ldap_group_response = ldap_compare($ldap_conn, $this->group_dn, $this->group_attrib, $this->dn);
+					if (!$ldap_group_response) {
+						$ldap_group_response = Ldap::isUserInLDAPGroup($ldap_conn, $this->search_base, $this->group_dn, $this->dn);
+					}
+				} elseif ($this->group_member_type == 2) {
+					/* Do a lookup to find this user's true DN. */
+					/* ldap_exop_whoami is not yet included in PHP. For reference, the
+					 * feature request: http://bugs.php.net/bug.php?id=42060
+					 * And the patch against lastest PHP release:
+					 * http://cvsweb.netbsd.org/bsdweb.cgi/pkgsrc/databases/php-ldap/files/ldap-ctrl-exop.patch
+					*/
+					$true_dn_result = ldap_search($ldap_conn, $this->search_base, 'userPrincipalName=' . $this->dn, array('dn'));
+					$first_entry    = ldap_first_entry($ldap_conn, $true_dn_result);
+
+					/* we will test in two ways */
+					if ($first_entry !== false) {
+						$true_dn     = ldap_get_dn($ldap_conn, $first_entry);
+						$ldap_group_response = ldap_compare($ldap_conn, $this->group_dn, $this->group_attrib, $true_dn);
+					} else {
+						$ldap_group_response = ldap_compare($ldap_conn, $this->group_dn, $this->group_attrib, $this->username);
+					}
+				}
+
+				if ($ldap_group_response === true) {
+					/* Auth ok */
+					$output = LdapError::GetErrorDetails(LdapError::Success);
+				} elseif ($ldap_group_response === false) {
+					$output = LdapError::GetErrorDetails(LdapError::InsufficientAccess);
+					Ldap::RecordError($output);
+					ldap_close($ldap_conn);
+					$this->RestoreCactiHandler();
+					return $output;
+				} else {
+					$output = LdapError::GetErrorDetails(LdapError::SearchFoundNoGroup);
 					Ldap::RecordError($output);
 					ldap_close($ldap_conn);
 					$this->RestoreCactiHandler();
 					return $output;
 				}
-			}
-
-			/* Bind to the LDAP directory */
-			cacti_log('LDAP: Binding with "' . $this->dn . '"', false, 'AUTH', POLLER_VERBOSITY_HIGH);
-			$ldap_response = ldap_bind($ldap_conn, $this->dn, $this->password);
-			if ($ldap_response) {
-				if ($this->group_require == 1) {
-					$ldap_group_response = false;
-
-					/* Process group membership if required */
-					if ($this->group_member_type == 1) {
-						$ldap_group_response = ldap_compare($ldap_conn, $this->group_dn, $this->group_attrib, $this->dn);
-					} else if ($this->group_member_type == 2) {
-						/* Do a lookup to find this user's true DN. */
-						/* ldap_exop_whoami is not yet included in PHP. For reference, the
-						 * feature request: http://bugs.php.net/bug.php?id=42060
-						 * And the patch against lastest PHP release:
-						 * http://cvsweb.netbsd.org/bsdweb.cgi/pkgsrc/databases/php-ldap/files/ldap-ctrl-exop.patch
-						*/
-						$true_dn_result = ldap_search($ldap_conn, $this->search_base, 'userPrincipalName=' . $this->dn, array('dn'));
-						$first_entry    = ldap_first_entry($ldap_conn, $true_dn_result);
-
-						/* we will test in two ways */
-						if ($first_entry !== false) {
-							$true_dn     = ldap_get_dn($ldap_conn, $first_entry);
-							$ldap_group_response = ldap_compare($ldap_conn, $this->group_dn, $this->group_attrib, $true_dn);
-						} else {
-							$ldap_group_response = ldap_compare($ldap_conn, $this->group_dn, $this->group_attrib, $this->username);
-						}
-					}
-
-					if ($ldap_group_response === true) {
-						/* Auth ok */
-						$output = LdapError::GetErrorDetails(LdapError::Success);
-					} else if ($ldap_group_response === false) {
-						$output = LdapError::GetErrorDetails(LdapError::InsufficientAccess);
-						Ldap::RecordError($output);
-						ldap_close($ldap_conn);
-						$this->RestoreCactiHandler();
-						return $output;
-					} else {
-						$output = LdapError::GetErrorDetails(LdapError::SearchFoundNoGroup);
-						Ldap::RecordError($output);
-						ldap_close($ldap_conn);
-						$this->RestoreCactiHandler();
-						return $output;
-					}
-				} else {
-					/* Auth ok - No group membership required */
-					$output = LdapError::GetErrorDetails(LdapError::Success);
-				}
 			} else {
-				/* unable to bind */
-				$ldap_error = ldap_errno($ldap_conn);
-				if ($ldap_error == 0x03) {
-					/* protocol error */
-					$output = LdapError::GetErrorDetails(LdapError::ProtocolErrorGeneral, null, $ldap_error);
-				} elseif ($ldap_error == 0x31) {
-					/* invalid credentials */
-					$output = LdapError::GetErrorDetails(LdapError::Failure);
-				} elseif ($ldap_error == 0x32) {
-					/* insuffient access */
-					$output = LdapError::GetErrorDetails(LdapError::InsufficientAccess);
-				} elseif ($ldap_error == 0x51) {
-					/* unable to connect to server */
-					$output = LdapError::GetErrorDetails(LdapError::ConnectionUnavailable);
-				} elseif ($ldap_error == 0x55) {
-					/* timeout */
-					$output = LdapError::GetErrorDetails(LdapError::ConnectionTimeout);
-				} else {
-					/* general bind error */
-					$output = LdapError::GetErrorDetails(LdapError::ProtocolErrorBind, null, $ldap_error);
-				}
+				/* Auth ok - No group membership required */
+				$output = LdapError::GetErrorDetails(LdapError::Success);
 			}
 		} else {
-			/* Error intializing LDAP */
-			$output = LdapError::GetErrorDetails(LdapError::MissingLdapObject);
+			/* unable to bind */
+			$ldap_error = ldap_errno($ldap_conn);
+			if ($ldap_error == 0x02) {
+				/* protocol error */
+				$output = LdapError::GetErrorDetails(LdapError::ProtocolErrorGeneral, $ldap_conn);
+			} elseif ($ldap_error == 0x31) {
+				/* invalid credentials */
+				$output = LdapError::GetErrorDetails(LdapError::Failure);
+			} elseif ($ldap_error == 0x32) {
+				/* insuffient access */
+				$output = LdapError::GetErrorDetails(LdapError::InsufficientAccess);
+			} elseif ($ldap_error == 0x51) {
+				/* unable to connect to server */
+				$output = LdapError::GetErrorDetails(LdapError::ConnectionUnavailable);
+			} elseif ($ldap_error == 0x55) {
+				/* timeout */
+				$output = LdapError::GetErrorDetails(LdapError::ConnectionTimeout);
+			} else {
+				/* general bind error */
+				$output = LdapError::GetErrorDetails(LdapError::ProtocolErrorBind, $ldap_conn);
+			}
 		}
 
 		/* Close LDAP connection */
@@ -556,29 +660,31 @@ class Ldap {
 	function Search() {
 		$output = array();
 
-		/* function check */
-		if (!function_exists('ldap_connect')) {
-			return LdapError::GetErrorDetails(LdapError::Disabled);
-		}
+		/* Determine connection method and create LDAP Object */
+		$this->SetLdapHandler();
 
-		/* validation */
-		if (empty($this->username)) {
-			$output = LdapError::GetErrorDetails(LdapError::UndefinedUsername);
-			Ldap::RecordError($output);
+		$connection = $this->Connect();
+
+		if (cacti_sizeof($connection['output'])) {
+			$this->RestoreCactiHandler();
 			return $output;
+		} elseif ($connection['ldap_conn'] === false) {
+			$this->RestoreCactiHandler();
+			return LdapError::GetErrorDetails(LdapError::MissingLdapObject);
 		}
 
-		/* Encode username */
-		$this->username = html_entity_decode($this->username, $this->GetMask(), 'UTF-8');
+		$ldap_conn = $connection['ldap_conn'];
 
-		/* strip bad chars from username - prevent altering filter from username */
+		/* Decode username, and remove bad characters */
+		$this->username = html_entity_decode($this->username, $this->GetMask(), 'UTF-8');
 		$this->username = str_replace(array('&', '|', '(', ')', '*', '>', '<', '!', '='), '', $this->username);
-		$this->dn = str_replace('<username>', $this->username, $this->dn);
+		$this->dn       = str_replace('<username>', $this->username, $this->dn);
 
 		if ($this->mode == '0') {
 			/* Just bind mode, make dn and return */
 			$output = LdapError::GetErrorDetails(LdapError::Success);
 			$output['dn'] = $this->dn;
+			$this->RestoreCactiHandler();
 			return $output;
 		} elseif ($this->mode == '2') {
 			/* Specific */
@@ -586,6 +692,7 @@ class Ldap {
 				$output = LdapError::GetErrorDetails(LdapError::UndefinedDnOrPassword);
 				$output['dn'] = $this->dn;
 				Ldap::RecordError($output, 'LDAP_SEARCH');
+				$this->RestoreCactiHandler();
 				return $output;
 			}
 		} elseif ($this->mode == '1'){
@@ -600,105 +707,51 @@ class Ldap {
 		$this->specific_password = html_entity_decode($this->specific_password, $this->GetMask(), 'UTF-8');
 		$this->specific_dn       = html_entity_decode($this->specific_dn, $this->GetMask(), 'UTF-8');
 
-		/* Searching mode */
-		$this->SetLdapHandler();
+		/* bind to the directory */
+		if (ldap_bind($ldap_conn, $this->specific_dn, $this->specific_password)) {
+			/* Search */
+			$ldap_results = ldap_search($ldap_conn, $this->search_base, $this->search_filter, array('dn'));
+			if ($ldap_results) {
+				$ldap_entries = ldap_get_entries($ldap_conn, $ldap_results);
 
-		if ($this->encryption == '1') {
-			/* This only works with OpenLDAP, I'm pretty sure this will not work with Solaris, Tony */
-			cacti_log('LDAP: Search using ldaps://' . $this->host . ':' . $this->port_ssl, false, 'AUTH', POLLER_VERBOSITY_HIGH);
-			$ldap_conn = ldap_connect('ldaps://' . $this->host . ':' . $this->port_ssl);
-		} else {
-			cacti_log('LDAP: Search using ldap://' . $this->host . ':' . $this->port, false, 'AUTH', POLLER_VERBOSITY_HIGH);
-			$ldap_conn = ldap_connect($this->host, $this->port);
-		}
-
-		if ($ldap_conn) {
-			/* Set protocol version */
-			if (!ldap_set_option($ldap_conn, LDAP_OPT_PROTOCOL_VERSION, $this->version)) {
-				/* protocol error */
-				$output = LdapError::GetErrorDetails(LdapError::ProtocolErrorVersion);
-				Ldap::RecordError($output, 'LDAP_SEARCH');
-				ldap_close($ldap_conn);
-
-				$this->RestoreCactiHandler();
-				return $output;
-			}
-
-			/* set referrals */
-			if ($this->referrals == '0') {
-				if (!ldap_set_option($ldap_conn, LDAP_OPT_REFERRALS, 0)) {
-					/* referrals set error */
-					$output = LdapError::GetErrorDetails(LdapError::ProtocolErrorReferral);
+				if ($ldap_entries['count'] == '1') {
+					/* single response return user dn */
+					$output = LdapError::GetErrorDetails(LdapError::Success);
+					$output['dn'] = $ldap_entries['0']['dn'];
 					Ldap::RecordError($output, 'LDAP_SEARCH');
-					ldap_close($ldap_conn);
-
-					$this->RestoreCactiHandler();
-					return $output;
-				}
-			}
-
-			/* start TLS if requested */
-			if ($this->encryption == '2') {
-				if (!ldap_start_tls($ldap_conn)) {
-					/* TLS startup error */
-					$output = LdapError::GetErrorDetails(LdapError::ProtocolErrorTls);
-					Ldap::RecordError($output, 'LDAP_SEARCH');
-					ldap_close($ldap_conn);
-
-					$this->RestoreCactiHandler();
-					return $output;
-				}
-			}
-
-			/* bind to the directory */
-			if (ldap_bind($ldap_conn, $this->specific_dn, $this->specific_password)) {
-				/* Search */
-				$ldap_results = ldap_search($ldap_conn, $this->search_base, $this->search_filter, array('dn'));
-				if ($ldap_results) {
-					$ldap_entries = ldap_get_entries($ldap_conn, $ldap_results);
-
-					if ($ldap_entries['count'] == '1') {
-						/* single response return user dn */
-						$output = LdapError::GetErrorDetails(LdapError::Success);
-						$output['dn'] = $ldap_entries['0']['dn'];
-						Ldap::RecordError($output, 'LDAP_SEARCH');
-					} elseif ($ldap_entries['count'] > 1) {
-						/* more than 1 result */
-						$output = LdapError::GetErrorDetails(LdapError::SearchFoundMultiUser);
-					} else {
-						/* no search results */
-						$output = LdapError::GetErrorDetails(LdapError::SearchFoundNoUserDN);
-					}
+				} elseif ($ldap_entries['count'] > 1) {
+					/* more than 1 result */
+					$output = LdapError::GetErrorDetails(LdapError::SearchFoundMultiUser);
 				} else {
-					/* no search results, user not found*/
-					$output = LdapError::GetErrorDetails(LdapError::SearchFoundNoUser);
+					/* no search results */
+					$output = LdapError::GetErrorDetails(LdapError::SearchFoundNoUserDN);
 				}
 			} else {
-				/* unable to bind */
-				$ldap_error = ldap_errno($ldap_conn);
-				if ($ldap_error == 0x03) {
-					/* protocol error */
-					$output = LdapError::GetErrorDetails(LdapError::ProtocolErrorGeneral,null,$ldap_error);
-				} elseif ($ldap_error == 0x31) {
-					/* invalid credentials */
-					$output = LdapError::GetErrorDetails(LdapError::Failure);
-				} elseif ($ldap_error == 0x32) {
-					/* insuffient access */
-					$output = LdapError::GetErrorDetails(LdapError::InsufficientAccess);
-				} elseif ($ldap_error == 0x51) {
-					/* unable to connect to server */
-					$output = LdapError::GetErrorDetails(LdapError::ConnectionUnavailable);
-				} elseif ($ldap_error == 0x55) {
-					/* timeout */
-					$output = LdapError::GetErrorDetails(LdapError::ConnectionTimeout);
-				} else {
-					/* general bind error */
-					$output = LdapError::GetErrorDetails(LdapError::ProtocolErrorBind, null, $ldap_error);
-				}
+				/* no search results, user not found*/
+				$output = LdapError::GetErrorDetails(LdapError::SearchFoundNoUser);
 			}
 		} else {
-			/* unable to setup connection */
-			$output = LdapError::GetErrorDetails(LdapError::MissingLdapObject);
+			/* unable to bind */
+			$ldap_error = ldap_errno($ldap_conn);
+			if ($ldap_error == 0x02) {
+				/* protocol error */
+				$output = LdapError::GetErrorDetails(LdapError::ProtocolErrorGeneral, $ldap_conn);
+			} elseif ($ldap_error == 0x31) {
+				/* invalid credentials */
+				$output = LdapError::GetErrorDetails(LdapError::Failure);
+			} elseif ($ldap_error == 0x32) {
+				/* insuffient access */
+				$output = LdapError::GetErrorDetails(LdapError::InsufficientAccess);
+			} elseif ($ldap_error == 0x51) {
+				/* unable to connect to server */
+				$output = LdapError::GetErrorDetails(LdapError::ConnectionUnavailable);
+			} elseif ($ldap_error == 0x55) {
+				/* timeout */
+				$output = LdapError::GetErrorDetails(LdapError::ConnectionTimeout);
+			} else {
+				/* general bind error */
+				$output = LdapError::GetErrorDetails(LdapError::ProtocolErrorBind, $ldap_conn);
+			}
 		}
 
 		ldap_close($ldap_conn);
@@ -708,30 +761,32 @@ class Ldap {
 		}
 
 		$this->RestoreCactiHandler();
+
 		return $output;
 	}
 
 	function Getcn() {
 		$output = array();
 
-		/* function check */
-		if (!function_exists('ldap_connect')) {
-			return LdapError::GetErrorDetails(LdapError::Disabled);
-		}
+		/* Determine connection method and create LDAP Object */
+		$this->SetLdapHandler();
 
-		/* validation */
-		if (empty($this->username)) {
-			$output = LdapError::GetErrorDetails(LdapError::Disabled);
-			Ldap::ReportError($output, 'LDAP_SEARCH');
+		$connection = $this->Connect();
+
+		if (cacti_sizeof($connection['output'])) {
+			$this->RestoreCactiHandler();
 			return $output;
+		} elseif ($connection['ldap_conn'] === false) {
+			$this->RestoreCactiHandler();
+			return LdapError::GetErrorDetails(LdapError::MissingLdapObject);
 		}
 
-		/* Encode username */
-		$this->username = html_entity_decode($this->username, $this->GetMask(), 'UTF-8');
+		$ldap_conn = $connection['ldap_conn'];
 
-		/* strip bad chars from username - prevent altering filter from username */
+		/* Decode username, and remove bad characters */
+		$this->username = html_entity_decode($this->username, $this->GetMask(), 'UTF-8');
 		$this->username = str_replace(array('&', '|', '(', ')', '*', '>', '<', '!', '='), '', $this->username);
-		$this->dn = str_replace('<username>', $this->username, $this->dn);
+		$this->dn       = str_replace('<username>', $this->username, $this->dn);
 
 		if ($this->mode == '0') {
 			/* Just bind mode, make dn and return */
@@ -757,112 +812,58 @@ class Ldap {
 		$this->specific_password = html_entity_decode($this->specific_password, $this->GetMask(), 'UTF-8');
 		$this->specific_dn       = html_entity_decode($this->specific_dn, $this->GetMask(), 'UTF-8');
 
-		/* Searching mode */
-		$this->SetLdapHandler();
+		/* bind to the directory */
+		if (ldap_bind($ldap_conn, $this->specific_dn, $this->specific_password)) {
+			/* Search */
+			$ldap_results = ldap_search($ldap_conn, $this->search_base, $this->search_filter, $this->cn);
 
-		if ($this->encryption == '1') {
-			/* This only works with OpenLDAP, I'm pretty sure this will not work with Solaris, Tony */
-			cacti_log('LDAP: GetCN using ldaps://' . $this->host . ':' . $this->port_ssl, false, 'AUTH', POLLER_VERBOSITY_HIGH);
-			$ldap_conn = ldap_connect('ldaps://' . $this->host . ':' . $this->port_ssl);
-		} else {
-			cacti_log('LDAP: GetCN using ldap://' . $this->host . ':' . $this->port_ssl, false, 'AUTH', POLLER_VERBOSITY_HIGH);
-			$ldap_conn = ldap_connect($this->host, $this->port);
-		}
-
-		if ($ldap_conn) {
-			/* Set protocol version */
-			if (!ldap_set_option($ldap_conn, LDAP_OPT_PROTOCOL_VERSION, $this->version)) {
-				/* protocol error */
-				$output = LdapError::GetErrorDetails(LdapError::ProtocolErrorVersion);
-				Ldap::RecordError($output, 'LDAP_SEARCH');
-				ldap_close($ldap_conn);
-
-				$this->RestoreCactiHandler();
-				return $output;
-			}
-
-			/* set referrals */
-			if ($this->referrals == '0') {
-				if (!ldap_set_option($ldap_conn, LDAP_OPT_REFERRALS, 0)) {
-					/* referrals set error */
-					$output = LdapError::GetErrorDetails(LdapError::ProtocolErrorReferral);
-					Ldap::RecordError($output, 'LDAP_SEARCH');
-					ldap_close($ldap_conn);
-
-					$this->RestoreCactiHandler();
-					return $output;
-				}
-			}
-
-			/* start TLS if requested */
-			if ($this->encryption == '2') {
-				if (!ldap_start_tls($ldap_conn)) {
-					/* TLS startup error */
-					$output = LdapError::GetErrorDetails(LdapError::ProtocolErrorTls);
-					Ldap::RecordError($output, 'LDAP_SEARCH');
-					ldap_close($ldap_conn);
-
-					$this->RestoreCactiHandler();
-					return $output;
-				}
-			}
-
-			/* bind to the directory */
-			if (ldap_bind($ldap_conn, $this->specific_dn, $this->specific_password)) {
-				/* Search */
-				$ldap_results = ldap_search($ldap_conn, $this->search_base, $this->search_filter, $this->cn);
-
-				if ($ldap_results) {
-					$ldap_entries =  ldap_get_entries($ldap_conn, $ldap_results);
-					/* We find 1 entries */
-					if ($ldap_entries['count'] == 1) {
-						$output = LdapError::GetErrorDetails(LdapError::Success);
-						// check if we got an full username entry
-						if (array_key_exists($this->cn[0], $ldap_entries[0])) {
-							$output['cn'][$this->cn[0]] = $ldap_entries[0][$this->cn[0]][0];
-						} else {
-							$output['cn'][$this->cn[0]] = '';
-						}
-
-						// check if we got an email entry
-						if(array_key_exists($this->cn[1], $ldap_entries[0])) {
-							$output['cn'][$this->cn[1]] = $ldap_entries[0][$this->cn[1]][0];
-						} else {
-							$output['cn'][$this->cn[1]] = '';
-						}
+			if ($ldap_results) {
+				$ldap_entries =  ldap_get_entries($ldap_conn, $ldap_results);
+				/* We find 1 entries */
+				if ($ldap_entries['count'] == 1) {
+					$output = LdapError::GetErrorDetails(LdapError::Success);
+					// check if we got an full username entry
+					if (array_key_exists($this->cn[0], $ldap_entries[0])) {
+						$output['cn'][$this->cn[0]] = $ldap_entries[0][$this->cn[0]][0];
 					} else {
-						$output = LdapError::GetErrorDetails(LdapError::SearchFoundMultiUser);
+						$output['cn'][$this->cn[0]] = '';
+					}
+
+					// check if we got an email entry
+					if(array_key_exists($this->cn[1], $ldap_entries[0])) {
+						$output['cn'][$this->cn[1]] = $ldap_entries[0][$this->cn[1]][0];
+					} else {
+						$output['cn'][$this->cn[1]] = '';
 					}
 				} else {
-					/* no search results, user not found*/
-					$output = LdapError::GetErrorDetails(LdapError::SearchFoundNoUserDN);
+					$output = LdapError::GetErrorDetails(LdapError::SearchFoundMultiUser);
 				}
 			} else {
-				/* unable to bind */
-				$ldap_error = ldap_errno($ldap_conn);
-				if ($ldap_error == 0x03) {
-					/* protocol error */
-					$output = LdapError::GetErrorDetails(LdapError::ProtocolErrorGeneral, null, $ldap_error);
-				} elseif ($ldap_error == 0x31) {
-					/* invalid credentials */
-					$output = LdapError::GetErrorDetails(LdapError::Failure);
-				} elseif ($ldap_error == 0x32) {
-					/* insuffient access */
-					$output = LdapError::GetErrorDetails(LdapError::InsufficientAccess);
-				} elseif ($ldap_error == 0x51) {
-					/* unable to connect to server */
-					$output = LdapError::GetErrorDetails(LdapError::ConnectionUnavailable);
-				} elseif ($ldap_error == 0x55) {
-					/* timeout */
-					$output = LdapError::GetErrorDetails(LdapError::ConnectionTimeout);
-				} else {
-					/* general bind error */
-					$output = LdapError::GetErrorDetails(LdapError::ProtocolErrorBind, null, $ldap_error);
-				}
+				/* no search results, user not found*/
+				$output = LdapError::GetErrorDetails(LdapError::SearchFoundNoUserDN);
 			}
 		} else {
-			/* Error intializing LDAP */
-			$output = LdapError::GetErrorDetails(LdapError::MissingLdapObject);
+			/* unable to bind */
+			$ldap_error = ldap_errno($ldap_conn);
+			if ($ldap_error == 0x02) {
+				/* protocol error */
+				$output = LdapError::GetErrorDetails(LdapError::ProtocolErrorGeneral, $ldap_conn);
+			} elseif ($ldap_error == 0x31) {
+				/* invalid credentials */
+				$output = LdapError::GetErrorDetails(LdapError::Failure);
+			} elseif ($ldap_error == 0x32) {
+				/* insuffient access */
+				$output = LdapError::GetErrorDetails(LdapError::InsufficientAccess);
+			} elseif ($ldap_error == 0x51) {
+				/* unable to connect to server */
+				$output = LdapError::GetErrorDetails(LdapError::ConnectionUnavailable);
+			} elseif ($ldap_error == 0x55) {
+				/* timeout */
+				$output = LdapError::GetErrorDetails(LdapError::ConnectionTimeout);
+			} else {
+				/* general bind error */
+				$output = LdapError::GetErrorDetails(LdapError::ProtocolErrorBind, $ldap_conn);
+			}
 		}
 
 		ldap_close($ldap_conn);
@@ -872,7 +873,17 @@ class Ldap {
 		}
 
 		$this->RestoreCactiHandler();
+
 		return $output;
 	}
+
+	function isUserInLDAPGroup($ldapConn, $ldapbasedn, $groupDN, $ldapUser) {
+		$query       = "(&(distinguishedName=$ldapUser)(memberOf:1.2.840.113556.1.4.1941:=$groupDN))";
+		$ldapSearch  = @ldap_search($ldapConn,$ldapbasedn,$query,array("dn"));
+		$ldapResults = @ldap_get_entries($ldapConn, $ldapSearch);
+
+		// user should only be returned once IF they're a member of the group
+		return isset($ldapResults['count']) && $ldapResults['count'] == 1 ? true:false;
+	}
 }
 
