@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2020 The Cacti Group                                 |
+ | Copyright (C) 2004-2021 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -44,6 +44,8 @@ function api_user_realm_auth($filename = '') {
 function api_plugin_hook($name) {
 	global $config, $plugin_hooks, $plugins_integrated;
 
+	static $hook_cache = array();
+
 	$args = func_get_args();
 	$ret = '';
 
@@ -51,17 +53,23 @@ function api_plugin_hook($name) {
 		return $args;
 	}
 
-	/* order the plugins by order */
-	$result = db_fetch_assoc_prepared('SELECT ph.name, ph.file, ph.function
-		FROM plugin_hooks AS ph
-		LEFT JOIN plugin_config AS pc
-		ON pc.directory = ph.name
-		WHERE ph.status = 1
-		AND hook = ?
-		ORDER BY pc.id ASC',
-		array($name),
-		true
-	);
+	if (!isset($hook_cache[$name])) {
+		/* order the plugins by order */
+		$result = db_fetch_assoc_prepared('SELECT ph.name, ph.file, ph.function
+			FROM plugin_hooks AS ph
+			LEFT JOIN plugin_config AS pc
+			ON pc.directory = ph.name
+			WHERE ph.status = 1
+			AND hook = ?
+			ORDER BY pc.id ASC',
+			array($name),
+			true
+		);
+
+		$hook_cache[$name] = $result;
+	} else {
+		$result = $hook_cache[$name];
+	}
 
 	if (!empty($result)) {
 		foreach ($result as $hdata) {
@@ -85,22 +93,30 @@ function api_plugin_hook($name) {
 function api_plugin_hook_function($name, $parm = NULL) {
 	global $config, $plugin_hooks, $plugins_integrated;
 
+	static $hook_cache = array();
+
 	$ret = $parm;
 	if (defined('IN_CACTI_INSTALL') || !db_table_exists('plugin_hooks')) {
 		return $ret;
 	}
 
-	/* order the plugins by order */
-	$result = db_fetch_assoc_prepared('SELECT ph.name, ph.file, ph.function
-		FROM plugin_hooks AS ph
-		LEFT JOIN plugin_config AS pc
-		ON pc.directory = ph.name
-		WHERE ph.status = 1
-		AND hook = ?
-		ORDER BY pc.id ASC',
-		array($name),
-		true
-	);
+	if (!isset($hook_cache[$name])) {
+		/* order the plugins by order */
+		$result = db_fetch_assoc_prepared('SELECT ph.name, ph.file, ph.function
+			FROM plugin_hooks AS ph
+			LEFT JOIN plugin_config AS pc
+			ON pc.directory = ph.name
+			WHERE ph.status = 1
+			AND hook = ?
+			ORDER BY pc.id ASC',
+			array($name),
+			true
+		);
+
+		$hook_cache[$name] = $result;
+	} else {
+		$result = $hook_cache[$name];
+	}
 
 	if (!empty($result)) {
 		foreach ($result as $hdata) {
@@ -453,23 +469,27 @@ function api_plugin_db_table_create($plugin, $table, $data) {
 
 		$sql .= ') ENGINE = ' . $data['type'];
 
+		if (isset($data['row_format']) && db_get_global_variable('innodb_file_format') == 'Barracuda') {
+			$sql .= ' ROW_FORMAT = ' . $data['row_format'];
+		}
+
 		if (isset($data['comment'])) {
 			$sql .= " COMMENT = '" . $data['comment'] . "'";
 		}
 
-		if (isset($data['charset'])) {
-			$sql .= ' DEFAULT CHARSET=' . $data['charset'];
-		}
-
-		if (isset($data['row_format']) && db_get_global_variable('innodb_file_format') == 'Barracuda') {
-			$sql .= ' ROW_FORMAT=' . $data['row_format'];
-		}
-
 		if (db_execute($sql)) {
 			db_execute_prepared("REPLACE INTO plugin_db_changes
 				(plugin, `table`, `column`, `method`)
 				VALUES (?, ?, '', 'create')",
 				array($plugin, $table));
+
+			if (isset($data['collate'])) {
+				db_execute("ALTER TABLE `$table` COLLATE = " . $data['collate']);
+			}
+
+			if (isset($data['charset'])) {
+				db_execute("ALTER TABLE `$table` CHARSET = " . $data['charset']);
+			}
 		}
 	}
 }
@@ -595,6 +615,10 @@ function api_plugin_can_install($plugin, &$message) {
 function api_plugin_install($plugin) {
 	global $config;
 
+	if (!defined('IN_CACTI_INSTALL')) {
+		define('IN_CACTI_INSTALL', 1);
+	}
+
 	$dependencies = api_plugin_get_dependencies($plugin);
 
 	$proceed = api_plugin_can_install($plugin, $message);
