@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2020 The Cacti Group                                 |
+ | Copyright (C) 2004-2021 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -551,7 +551,7 @@ function update_graph_data_source_output_type($local_graph_id, $output_type_id)
 			AND data_input_field_id = ?',
 			array($data['id'], $output_type_field_id));
 
-		if ($snmp_query_graph_id != $output_type_id) {
+		if ($snmp_query_graph_id != $output_type_id && $output_type_id > 0) {
 			db_execute_prepared('UPDATE data_input_data
 				SET value = ?
 				WHERE data_template_data_id = ?
@@ -569,6 +569,87 @@ function update_graph_data_source_output_type($local_graph_id, $output_type_id)
 	}
 }
 
+/**
+ * graph_template_has_override
+ *
+ * This function determines if a Graph Template has fields that
+ * allow changing of their values at create time.  Data that
+ * is considered for override includes data in:
+ *
+ * Data Input Fields
+ * Data Template Data Fields
+ * Graph Template Fields
+ *
+ * @param $graph_template_id
+ *
+ * @return boolean override allowed
+ */
+function graph_template_has_override($graph_template_id) {
+	$graph_template = db_fetch_row_prepared('SELECT *
+		FROM graph_templates_graph
+		WHERE graph_template_id = ?
+		AND local_graph_id = 0',
+		array($graph_template_id));
+
+	// Check the Graph Template first for adherence
+	if (cacti_sizeof($graph_template)) {
+		foreach($graph_template as $field => $value) {
+			if (substr($field, 0, 2) == 't_') {
+				if ($value == 'on') {
+					return true;
+				}
+			}
+		}
+	}
+
+	// Next let's check it's source Data Templates
+	$data_templates = db_fetch_assoc_prepared('SELECT DISTINCT dtd.*
+		FROM data_template_data AS dtd
+		INNER JOIN data_template_rrd AS dtr
+		ON dtd.data_template_id = dtr.data_template_id
+		INNER JOIN graph_templates_item AS gti
+		ON dtr.id = gti.task_item_id
+		WHERE gti.graph_template_id = ?
+		AND dtd.local_data_id = 0
+		AND dtr.local_data_id = 0
+		AND gti.hash != ""',
+		array($graph_template_id));
+
+	if (cacti_sizeof($data_templates)) {
+		foreach($data_templates as $dtd) {
+			foreach($dtd as $field => $value) {
+				if (substr($field, 0, 2) == 't_') {
+					if ($value == 'on') {
+						return true;
+					}
+				}
+			}
+
+			// Lastly check the data input fields
+			$input_fields = db_fetch_assoc_prepared('SELECT dif.data_input_id, did.t_value, did.value, dtd.name
+				FROM data_template_data AS dtd
+				INNER JOIN data_template AS dt
+				ON dt.id = dtd.data_template_id
+				INNER JOIN data_input_data AS did
+				ON did.data_template_data_id = dtd.id
+				INNER JOIN data_input_fields AS dif
+				ON dif.id = did.data_input_field_id
+				WHERE dt.hash != ""
+				AND dtd.id = ?
+				AND dtd.local_data_id = 0
+				AND dif.input_output = "in"
+				AND did.t_value = "on"',
+				array($dtd['id']));
+
+			if (cacti_sizeof($input_fields)) {
+				return true;
+			}
+		}
+	}
+
+	return false;
+}
+
 function parse_graph_template_id($value) {
 	if (strpos($value, '_') !== false) {
 		$template_parts = explode('_', $value);
@@ -1361,6 +1442,8 @@ function create_complete_graph_from_template($graph_template_id, $host_id, $snmp
 		api_plugin_hook_function('create_complete_graph_from_template', $save);
 	}
 
+	set_config_option('sess_allowed_templates_lastchange', time());
+
 	return $cache_array;
 }
 
@@ -1636,27 +1719,8 @@ function create_save_graph($host_id, $form_type, $form_id1, $form_array2, $value
 	if ($form_type == 'cg') {
 		$snmp_query_array = array();
 
-		$return_array = create_complete_graph_from_template($graph_template_id, $host_id, $snmp_query_array, $values['cg']);
-
-		if ($return_array !== false) {
-			debug_log_insert('new_graphs', __esc('Created: %s', get_graph_title($return_array['local_graph_id'])));
-
-			/* lastly push host-specific information to our data sources */
-			if (cacti_sizeof($return_array['local_data_id'])) { # we expect at least one data source associated
-				foreach($return_array['local_data_id'] as $item) {
-					push_out_host($host_id, $item);
-				}
-			} else {
-				debug_log_insert('new_graphs', __('ERROR: No Data Source associated. Check Template'));
-			}
-		} else {
-			debug_log_insert('new_graphs', __('ERROR: Whitelist Validation Failed. Check Data Input Method'));
-		}
-	} elseif ($form_type == 'sg') {
-		foreach ($snmp_index_array as $snmp_index => $true) {
-			$snmp_query_array['snmp_index'] = decode_data_query_index($snmp_index, $snmp_query_array['snmp_query_id'], $host_id);
-
-			$return_array = create_complete_graph_from_template($graph_template_id, $host_id, $snmp_query_array, $values['sg'][$snmp_query_array['snmp_query_id']]);
+		if (test_data_sources($graph_template_id, $host_id)) {
+			$return_array = create_complete_graph_from_template($graph_template_id, $host_id, $snmp_query_array, $values['cg']);
 
 			if ($return_array !== false) {
 				debug_log_insert('new_graphs', __esc('Created: %s', get_graph_title($return_array['local_graph_id'])));
@@ -1672,6 +1736,43 @@ function create_save_graph($host_id, $form_type, $form_id1, $form_array2, $value
 			} else {
 				debug_log_insert('new_graphs', __('ERROR: Whitelist Validation Failed. Check Data Input Method'));
 			}
+		} else {
+			$name = db_fetch_cell_prepared('SELECT name
+				FROM graph_templates
+				WHERE id = ?',
+				array($graph_template_id));
+
+			debug_log_insert('new_graphs', __('Graph Not created for ' . $name . ' due to bad data'));
+		}
+	} elseif ($form_type == 'sg') {
+		foreach ($snmp_index_array as $snmp_index => $true) {
+			$snmp_query_array['snmp_index'] = decode_data_query_index($snmp_index, $snmp_query_array['snmp_query_id'], $host_id);
+
+			if (test_data_sources($graph_template_id, $host_id, $snmp_query_array['snmp_query_id'], $snmp_query_array['snmp_index'])) {
+				$return_array = create_complete_graph_from_template($graph_template_id, $host_id, $snmp_query_array, $values['sg'][$snmp_query_array['snmp_query_id']]);
+
+				if ($return_array !== false) {
+					debug_log_insert('new_graphs', __esc('Created: %s', get_graph_title($return_array['local_graph_id'])));
+
+					/* lastly push host-specific information to our data sources */
+					if (cacti_sizeof($return_array['local_data_id'])) { # we expect at least one data source associated
+						foreach($return_array['local_data_id'] as $item) {
+							push_out_host($host_id, $item);
+						}
+					} else {
+						debug_log_insert('new_graphs', __('ERROR: No Data Source associated. Check Template'));
+					}
+				} else {
+					debug_log_insert('new_graphs', __('ERROR: Whitelist Validation Failed. Check Data Input Method'));
+				}
+			} else {
+				$name = db_fetch_cell_prepared('SELECT name
+					FROM snmp_query
+					WHERE id = ?',
+					array($snmp_query_array['snmp_query_id']));
+
+				debug_log_insert('new_graphs', __('NOTE: Graph not for Data Query ' . $name . ' and index ' .  $snmp_query_array['snmp_index'] . ' due to Data Source verification failure.'));
+			}
 		}
 	}
 }
