@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2020 The Cacti Group                                 |
+ | Copyright (C) 2004-2021 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -82,8 +82,6 @@ function update_data_source_title_cache_from_host($host_id, $query_id = 0, $ids
 	}
 
 	if (cacti_sizeof($data)) {
-		cacti_log('Updating ' . cacti_sizeof($data) . ' Data Source');
-
 		foreach ($data as $item) {
 			update_data_source_title_cache($item['id']);
 		}
@@ -178,9 +176,21 @@ function update_graph_title_cache_from_host($host_id, $query_id = 0, $ids = arra
 /* update_graph_title_cache - updates the title cache for a single graph
    @arg $local_graph_id - (int) the ID of the graph to update the title cache for */
 function update_graph_title_cache($local_graph_id) {
+	$old_title = db_fetch_cell_prepared('SELECT title_cache
+		FROM graph_templates_graph
+		WHERE local_graph_id = ?',
+		array($local_graph_id));
+
 	$graph_title = get_graph_title($local_graph_id);
 
-	if (strstr($graph_title, '|query_') === false && strstr($graph_title, '|host_') === false) {
+	if (strstr($graph_title, '|query_') !== false || strstr($graph_title, '|host_') !== false) {
+		if ($old_title == '') {
+			db_execute_prepared('UPDATE graph_templates_graph
+				SET title_cache = ?
+				WHERE local_graph_id = ?',
+				array($graph_title, $local_graph_id));
+		}
+	} else {
 		db_execute_prepared('UPDATE graph_templates_graph
 			SET title_cache = ?
 			WHERE local_graph_id = ?',
