@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2021 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -314,7 +314,7 @@ function domain_edit() {
 
 	if (!isempty_request_var('domain_id')) {
 		$domain = db_fetch_row_prepared('SELECT * FROM user_domains WHERE domain_id = ?', array(get_request_var('domain_id')));
-		$header_label = __('User Domain [edit: %s]', html_escape($domain['domain_name']));
+		$header_label = __esc('User Domain [edit: %s]', $domain['domain_name']);
 	} else {
 		$header_label = __('User Domain [new]');
 	}
@@ -471,7 +471,7 @@ function domain_edit() {
 			'description' => __('Search filter to use to locate the user in the LDAP directory, such as for windows: <i>"(&amp;(objectclass=user)(objectcategory=user)(userPrincipalName=&lt;username&gt;*))"</i> or for OpenLDAP: <i>"(&(objectClass=account)(uid=&lt;username&gt))"</i>.  "&lt;username&gt" is replaced with the username that was supplied at the login prompt.'),
 			'method' => 'textbox',
 			'value' => '|arg1:search_filter|',
-			'max_length' => '255'
+			'max_length' => '512'
 			),
 		'specific_dn' => array(
 			'friendly_name' => __('Search Distinguished Name (DN)'),
@@ -553,7 +553,7 @@ function domain_edit() {
 
 	function initSearch() {
 		switch($('#mode').val()) {
-		case "0":
+		case '0':
 			$('#row_search_base_header').hide();
 			$('#row_search_base').hide();
 			$('#row_search_filter').hide();
@@ -562,7 +562,7 @@ function domain_edit() {
 			$('#row_cn_full_name').hide();
 			$('#row_cn_email').hide();
 			break;
-		case "1":
+		case '1':
 			$('#row_search_base_header').show();
 			$('#row_search_base').show();
 			$('#row_search_filter').show();
@@ -571,7 +571,7 @@ function domain_edit() {
 			$('#row_cn_full_name').hide();
 			$('#row_cn_email').hide();
 			break;
-		case "2":
+		case '2':
 			$('#row_search_base_header').show();
 			$('#row_search_base').show();
 			$('#row_search_filter').show();
