@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2020 The Cacti Group                                 |
+ | Copyright (C) 2004-2021 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -215,7 +215,7 @@ function utilities_view_tech() {
 		/* Get RRDtool version */
 		$rrdtool_version = __('Unknown');
 		$rrdtool_release = __('Unknown');
-		$storage_location = read_config_option('$storage_location');
+		$storage_location = read_config_option('storage_location');
 
 		$out_array = array();
 
@@ -225,7 +225,7 @@ function utilities_view_tech() {
 			}
 		}else {
 			$rrdtool_pipe = rrd_init();
-			$out_array = rrdtool_execute('info', false, RRDTOOL_OUTPUT_STDOUT, $rrdtool_pipe, 'WEBLOG');
+			$out_array[] = rrdtool_execute('info', false, RRDTOOL_OUTPUT_STDOUT, $rrdtool_pipe, 'WEBLOG');
 			rrd_close($rrdtool_pipe);
 		}
 
@@ -378,19 +378,63 @@ function utilities_view_tech() {
 		print '</td>';
 		form_end_row();
 
+		$processes = db_fetch_cell('SELECT
+			GROUP_CONCAT(
+				CONCAT("' . __('Name: ') . '", name, ", ' . __('Procs: ') . '", processes) SEPARATOR "<br>"
+			) AS poller
+			FROM poller
+			WHERE disabled=""');
+
+		$threads = db_fetch_cell('SELECT
+			GROUP_CONCAT(
+				CONCAT("' . __('Name: ') . '", name, ", ' . __('Threads: ') . '", threads) SEPARATOR "<br>"
+			) AS poller
+			FROM poller
+			WHERE disabled=""');
+
 		form_alternate_row();
 		print '<td>' . __('Concurrent Processes') . '</td>';
-		print '<td>' . read_config_option('concurrent_processes') . '</td>';
+		print '<td>' . $processes . '</td>';
 		form_end_row();
 
 		form_alternate_row();
 		print '<td>' . __('Max Threads') . '</td>';
-		print '<td>' . read_config_option('max_threads') . '</td>';
+		print '<td>' . $threads . '</td>';
 		form_end_row();
 
+		$script_servers = read_config_option('php_servers');
+
 		form_alternate_row();
 		print '<td>' . __('PHP Servers') . '</td>';
-		print '<td>' . read_config_option('php_servers') . '</td>';
+		print '<td>' . html_escape($script_servers) . '</td>';
+		form_end_row();
+
+		$max_connections  = db_fetch_row('SHOW GLOBAL VARIABLES LIKE "max_connections"');
+		if (cacti_sizeof($max_connections)) {
+			$max_connections = $max_connections['Value'];
+		} else {
+			$max_connections = 0;
+		}
+
+		$total_dc_threads = db_fetch_cell("SELECT
+			SUM((processes * threads) + (processes * $script_servers)) AS threads
+			FROM poller
+			WHERE disabled = ''");
+
+		$recommend_mc = $total_dc_threads + 100;
+
+		if ($recommend_mc > $max_connections) {
+			$db_connections = '<span class="deviceDown">' . __('Current: %s, Min Required: %s', $max_connections, $recommend_mc) . '</span>';
+		} else {
+			$db_connections = '<span class="deviceUp">' . __('Current: %s, Min Required: %s', $max_connections, $recommend_mc) . '</span>';
+		}
+
+		form_alternate_row();
+		print '<td>' . __('Minimum Connections:') . '</td>';
+		print '<td>' . $db_connections . '<br>' .
+			__('Assumes 100 spare connections for Web page users and other various connections.') . '<br>' .
+			__('The minimum required can vary greatly if there is heavy user Graph viewing activity.') . '<br>' .
+			__('Each browser tab can use upto 10 connections depending on the browser.') . '</td>';
 		form_end_row();
 
 		form_alternate_row();
@@ -626,15 +670,12 @@ function utilities_view_tech() {
 		$php_info = utilities_php_modules();
 
 		html_section_header(__('PHP Module Information'), 2);
-		form_alternate_row();
 		$php_info = str_replace(
 			array('width="600"', 'th colspan="2"', ','),
 			array('', 'th class="subHeaderColumn"', ', '),
 			$php_info
 		);
-		print "<td colspan='2'>" . $php_info . '</td>';
-
-		form_end_row();
+		print "<tr><td colspan='2'>" . $php_info . '</td></tr>';
 	}
 
 	html_end_box();
@@ -771,7 +812,7 @@ function utilities_view_user_log() {
 
 							if (cacti_sizeof($users)) {
 								foreach ($users as $user) {
-									print "<option value='" . $user['username'] . "'"; if (get_request_var('username') == $user['username']) { print ' selected'; } print '>' . $user['username'] . '</option>';
+									print "<option value='" . html_escape($user['username']) . "'"; if (get_request_var('username') == $user['username']) { print ' selected'; } print '>' . html_escape($user['username']) . '</option>';
 								}
 							}
 							?>
@@ -991,28 +1032,26 @@ function utilities_clear_user_log() {
 function utilities_view_logfile() {
 	global $log_tail_lines, $page_refresh_interval, $config;
 
-	$logfile = read_config_option('path_cactilog');
-	$logbase = basename($logfile);
+	$logfile = basename(get_nfilter_request_var('filename'));
+	$logbase = basename(read_config_option('path_cactilog'));
 
-	if (isset_request_var('filename')) {
-		$requestedFile = dirname($logfile) . '/' . basename(get_nfilter_request_var('filename'));
-		if (file_exists($requestedFile)) {
-			$logfile = $requestedFile;
-		} else {
-			$logfile = read_config_option('path_cactilog');
-		}
+	if ($logfile == '') {
+		$logfile = $logbase;
 	}
 
 	if ($logfile == '') {
-		$logfile = $config['base_path'] . '/log/cacti.log';
+		$logfile = 'cacti.log';
 	}
 
-	if (get_nfilter_request_var('filename') != '') {
-		if (strpos(get_nfilter_request_var('filename'), $logbase) === false) {
-			raise_message('clog_invalid');
-			header('Location: utilities.php?action=view_logfile&filename=' . $logbase);
-			exit(0);
-		}
+	$logname = '';
+	$logpath = '';
+
+	if (!clog_validate_filename($logfile, $logpath, $logname, true)) {
+		raise_message('clog_invalid');
+		header('Location: utilities.php?action=view_logfile&filename=' . $logbase);
+		exit(0);
+	} else {
+		$logfile = $logpath . '/' . $logfile;
 	}
 
 	/* ================= input validation and session storage ================= */
@@ -1132,7 +1171,7 @@ function utilities_view_logfile() {
 
 							if (cacti_sizeof($logFileArray)) {
 								foreach ($logFileArray as $logFile) {
-									print "<option value='" . $logFile . "'";
+									print "<option value='" . html_escape($logFile) . "'";
 
 									if (get_nfilter_request_var('filename') == $logFile) {
 										print ' selected';
@@ -1143,7 +1182,7 @@ function utilities_view_logfile() {
 									$logDate = cacti_count($logParts) < 2 ? '' : $logParts[1] . (isset($logParts[2]) ? '-' . $logParts[2]:'');
 									$logName = $logParts[0];
 
-									print '>' . $logName . ($logDate != '' ? ' [' . substr($logDate,4) . ']':'') . '</option>';
+									print '>' . html_escape($logName . ($logDate != '' ? ' [' . substr($logDate,4) . ']':'')) . '</option>';
 								}
 							}
 							?>
@@ -1247,7 +1286,7 @@ function utilities_view_logfile() {
 	$refreshTime  = get_request_var('refresh');
 	$message_type = get_request_var('message_type');
 	$tail_lines   = get_request_var('tail_lines');
-	$base_url     = 'utilities.php?action=view_logfile&rfilter='.$rfilter.'&reverse='.$reverse.'&refresh='.$refreshTime.'&message_type='.$message_type.'&tail_lines='.$tail_lines.'&filename='.basename($logfile);
+	$base_url     = 'utilities.php?action=view_logfile&filename='.basename($logfile);
 
 	$nav = html_nav_bar($base_url, MAX_DISPLAY_PAGES, $page_nr, $number_of_lines, $total_rows, 13, __('Entries'), 'page', 'main');
 
@@ -1768,7 +1807,7 @@ function utilities_view_poller_cache() {
 
 							if (cacti_sizeof($templates)) {
 								foreach ($templates as $template) {
-									print "<option value='" . $template['id'] . "'"; if (get_request_var('template_id') == $template['id']) { print ' selected'; } print '>' . title_trim(html_escape($template['name']), 40) . '</option>';
+									print "<option value='" . $template['id'] . "'"; if (get_request_var('template_id') == $template['id']) { print ' selected'; } print '>' . html_escape($template['name']) . '</option>';
 								}
 							}
 							?>
@@ -1958,7 +1997,7 @@ function utilities_view_poller_cache() {
 }
 
 function utilities() {
-	global $utilities;
+	global $config, $utilities;
 
 	$utilities[__('Technical Support')] = array(
 		__('Technical Support') => array(
@@ -1986,10 +2025,12 @@ function utilities() {
 		),
 		__('Rebuild Poller Cache') => array(
 			'link'  => 'utilities.php?action=clear_poller_cache',
+			'mode'  => 'online',
 			'description' => __('The Poller Cache will be re-generated if you select this option. Use this option only in the event of a database crash if you are experiencing issues after the crash and have already run the database repair tools.  Alternatively, if you are having problems with a specific Device, simply re-save that Device to rebuild its Poller Cache.  There is also a command line interface equivalent to this command that is recommended for large systems.  <i class="deviceDown">NOTE: On large systems, this command may take several minutes to hours to complete and therefore should not be run from the Cacti UI.  You can simply run \'php -q cli/rebuild_poller_cache.php --help\' at the command line for more information.</i>')
 		),
 		__('Rebuild Resource Cache') => array(
 			'link'  => 'utilities.php?action=rebuild_resource_cache',
+			'mode'  => 'online',
 			'description' => __('When operating multiple Data Collectors in Cacti, Cacti will attempt to maintain state for key files on all Data Collectors.  This includes all core, non-install related website and plugin files.  When you force a Resource Cache rebuild, Cacti will clear the local Resource Cache, and then rebuild it at the next scheduled poller start.  This will trigger all Remote Data Collectors to recheck their website and plugin files for consistency.')
 		),
 	);
@@ -2004,6 +2045,7 @@ function utilities() {
 	$utilities[__('Data Source Statistics Utilities')] = array(
 		__('Purge Data Source Statistics') => array(
 			'link'  => 'utilities.php?action=purge_data_source_statistics',
+			'mode'  => 'online',
 			'description' => __('This menu pick will purge all existing Data Source Statistics from the Database.  If Data Source Statistics is enabled, the Data Sources Statistics will start collection again on the next Data Collector pass.')
 		),
 	);
@@ -2011,6 +2053,7 @@ function utilities() {
 	$utilities[__('RRD Utilities')] = array(
 		__('RRDfile Cleaner') => array(
 			'link'  => 'rrdcleaner.php',
+			'mode'  => 'online',
 			'description' => __('When you delete Data Sources from Cacti, the corresponding RRDfiles are not removed automatically.  Use this utility to facilitate the removal of these old files.')
 		),
 	);
@@ -2019,18 +2062,22 @@ function utilities() {
 		$utilities[__('SNMP Agent Utilities')] = array(
 			__('View SNMP Agent Cache') => array(
 				'link'  => 'utilities.php?action=view_snmpagent_cache',
+				'mode'  => 'online',
 				'description' => __('This shows all objects being handled by the SNMP Agent.')
 			),
 			__('Rebuild SNMP Agent Cache') => array(
 				'link'  => 'utilities.php?action=rebuild_snmpagent_cache',
+				'mode'  => 'online',
 				'description' => __('The SNMP cache will be cleared and re-generated if you select this option. Note that it takes another poller run to restore the SNMP cache completely.')
 			),
 			__('View SNMP Agent Notification Log') => array(
 				'link'  => 'utilities.php?action=view_snmpagent_events',
+				'mode'  => 'online',
 				'description' => __('This menu pick allows you to view the latest events SNMP Agent has handled in relation to the registered notification receivers.')
 			),
 			__('SNMP Notification Receivers') => array(
 				'link'  => 'managers.php',
+				'mode'  => 'online',
 				'description' => __('Allows Administrators to maintain SNMP notification receivers.')
 			),
 		);
@@ -2041,16 +2088,25 @@ function utilities() {
 	html_start_box(__('Cacti System Utilities'), '100%', '', '3', 'center', '');
 
 	foreach($utilities as $header => $content) {
-		html_section_header($header, 2);
+		$i = 0;
+
 		foreach($content as $title => $details) {
-			form_alternate_row();
-			print "<td class='nowrap' style='vertical-align:top;'>";
-			print "<a class='hyperLink' href='" . html_escape($details['link']) . "'>" . $title . '</a>';
-			print '</td>';
-			print '<td>';
-			print $details['description'];
-			print '</td>';
-			form_end_row();
+			if ((isset($details['mode']) && $details['mode'] == 'online' && $config['connection'] == 'online') || !isset($details['mode'])) {
+				if ($i == 0) {
+					html_section_header($header, 2);
+				}
+
+				form_alternate_row();
+				print "<td class='nowrap' style='vertical-align:top;'>";
+				print "<a class='hyperLink' href='" . html_escape($details['link']) . "'>" . $title . '</a>';
+				print '</td>';
+				print '<td>';
+				print $details['description'];
+				print '</td>';
+				form_end_row();
+
+				$i++;
+			}
 		}
 	}
 
@@ -2167,10 +2223,24 @@ function boost_display_run_status() {
 		$max_data_length = $table['MAX_DATA_LENGTH'];
 	}
 
-	$total_records  = $pending_records + $arch_records;
-	$avg_row_length = ($total_records ? intval($data_length / $total_records) : 0);
+	if ($config['connection'] == 'online') {
+		$pending_ds = db_fetch_cell('SELECT COUNT(local_data_id) FROM poller_output_boost_local_data_ids');
+	} else {
+		$pending_ds = 0;
+	}
 
-	$total_data_sources = db_fetch_cell('SELECT COUNT(*) FROM poller_item');
+	$poller_items = db_fetch_cell('SELECT COUNT(local_data_id) FROM poller_item');
+	$data_sources = db_fetch_cell('SELECT COUNT(DISTINCT local_data_id) FROM poller_item');
+	$pi_ds        = $poller_items / $data_sources;
+
+	if ($pending_ds == 0) {
+		$remaining = $arch_records;
+	} else {
+		$remaining = $arch_records * (($pending_ds * $pi_ds) / $data_sources);
+	}
+
+	$total_records  = $pending_records + $remaining;
+	$avg_row_length = ($total_records ? intval($data_length / $total_records) : 0);
 
 	$boost_status = read_config_option('boost_poller_status', true);
 	if ($boost_status != '') {
@@ -2178,11 +2248,17 @@ function boost_display_run_status() {
 
 		$boost_status_date  = $boost_status_array[1];
 
-		if (substr_count($boost_status_array[0], 'complete'))    $boost_status_text = __('Idle');
-		elseif (substr_count($boost_status_array[0], 'running')) $boost_status_text = __('Running');
-		elseif (substr_count($boost_status_array[0], 'overrun')) $boost_status_text = __('Overrun Warning');
-		elseif (substr_count($boost_status_array[0], 'timeout')) $boost_status_text = __('Timed Out');
-		else   $boost_status_text = __('Other');
+		if (substr_count($boost_status_array[0], 'complete')) {
+			$boost_status_text = __('Idle');
+		} elseif (substr_count($boost_status_array[0], 'running')) {
+			$boost_status_text = __('Running');
+		} elseif (substr_count($boost_status_array[0], 'overrun')) {
+			$boost_status_text = __('Overrun Warning');
+		} elseif (substr_count($boost_status_array[0], 'timeout')) {
+			$boost_status_text = __('Timed Out');
+		} else {
+			$boost_status_text = __('Other');
+		}
 	} else {
 		$boost_status_text = __('Never Run');
 		$boost_status_date = '';
@@ -2245,26 +2321,47 @@ function boost_display_run_status() {
 		$cache_files    = '<strong>' . __('WARNING:') . '</strong> ' . __('N/A');
 	}
 
+	$running = db_fetch_cell('SELECT COUNT(*) FROM processes WHERE tasktype="boost" AND taskname="child"');
+
 	$i = 0;
 
 	/* boost status display */
 	html_section_header(__('Current Boost Status'), 2);
 
-	form_alternate_row();
-	print '<td>' . __('Boost On-demand Updating:') . '</td><td>' . ($rrd_updates == '' ? 'Disabled' : $boost_status_text) . '</td>';
+	if ($config['connection'] == 'online') {
+		form_alternate_row();
+		print '<td>' . __('Boost On-demand Updating:') . '</td><td>' . ($rrd_updates == '' ? 'Disabled' : $boost_status_text) . '</td>';
+
+		if ($running > 0) {
+			form_alternate_row();
+			print '<td>' . __('Running Processes:') . '</td><td>' . ($running) . '</td>';
+		}
+	}
 
 	form_alternate_row();
-	print '<td>' . __('Total Data Sources:') . '</td><td>' . number_format_i18n($total_data_sources, -1) . '</td>';
+	print '<td>' . __('Total Poller Items:') . '</td><td>' . number_format_i18n($poller_items, -1) . '</td>';
+
+	$premaining = round(($pending_ds / $data_sources) * 100, 1);
 
 	if ($total_records) {
 		form_alternate_row();
-		print '<td>' . __('Pending Boost Records:') . '</td><td>' . number_format_i18n($pending_records, -1) . '</td>';
+		print '<td>' . __('Total Data Sources:') . '</td><td>' . number_format_i18n($data_sources, -1) . '</td>';
+
+		if ($config['connection'] == 'online') {
+			form_alternate_row();
+			print '<td>' . __('Remaining Data Sources:') . '</td><td>' . ($pending_ds > 0 ? number_format_i18n($pending_ds, -1) . " ($premaining %)":__('TBD')) . '</td>';
+		}
 
 		form_alternate_row();
-		print '<td>' . __('Archived Boost Records:') . '</td><td>' . number_format_i18n($arch_records, -1) . '</td>';
+		print '<td>' . __('Queued Boost Records:') . '</td><td>' . number_format_i18n($pending_records, -1) . '</td>';
 
-		form_alternate_row();
-		print '<td>' . __('Total Boost Records:') . '</td><td>' . number_format_i18n($total_records, -1) . '</td>';
+		if ($config['connection'] == 'online') {
+			form_alternate_row();
+			print '<td>' . __('Approximate in Process:') . '</td><td>' . number_format_i18n($remaining, -1) . '</td>';
+
+			form_alternate_row();
+			print '<td>' . __('Total Boost Records:') . '</td><td>' . number_format_i18n($total_records, -1) . '</td>';
+		}
 	}
 
 	/* boost status display */
@@ -2326,66 +2423,90 @@ function boost_display_run_status() {
 	form_alternate_row();
 	print '<td>' . __('Estimated Maximum Records:') . '</td><td>' . $max_table_records . ' Records</td>';
 
-	/* boost last runtime display */
-	html_section_header(__('Runtime Statistics'), 2);
+	if ($config['connection'] == 'online') {
+		/* boost last runtime display */
+		html_section_header(__('Runtime Statistics'), 2);
 
-	form_alternate_row();
-	print '<td class="utilityPick">' . __('Last Start Time:') . '</td><td>' . (is_numeric($last_run_time) ? date('Y-m-d H:i:s', $last_run_time):$last_run_time) . '</td>';
+		form_alternate_row();
+		print '<td class="utilityPick">' . __('Last Start Time:') . '</td><td>' . (is_numeric($last_run_time) ? date('Y-m-d H:i:s', $last_run_time):$last_run_time) . '</td>';
 
-	form_alternate_row();
-	print '<td class="utilityPick">' . __('Last Run Duration:') . '</td><td>';
+		form_alternate_row();
+		print '<td class="utilityPick">' . __('Last Run Duration:') . '</td><td>';
 
-	if (is_numeric($boost_last_run_duration)) {
-		print (($boost_last_run_duration > 60) ? __('%d minutes', (int)($boost_last_run_duration/60)) : '' ) . __('%d seconds', $boost_last_run_duration%60);
-		if ($rrd_updates != ''){ print ' (' . __('%0.2f percent of update frequency)', round(100*$boost_last_run_duration/$update_interval/60));}
-	} else {
-		print __('N/A');
+		if (is_numeric($boost_last_run_duration)) {
+			print (($boost_last_run_duration > 60) ? __('%d minutes', (int)($boost_last_run_duration/60)) . ', ': '') . __('%d seconds', $boost_last_run_duration%60);
+
+			if ($rrd_updates != ''){
+				print ' (' . __('%0.2f percent of update frequency)', round(100*$boost_last_run_duration/$update_interval/60));
+			}
+		} else {
+			print __('N/A');
+		}
+		print '</td>';
+
+		form_alternate_row();
+		print '<td class="utilityPick">' . __('RRD Updates:') . '</td><td>' . ($boost_rrds_updated != '' ? number_format_i18n($boost_rrds_updated, -1):'-') . '</td>';
+
+		form_alternate_row();
+		print '<td class="utilityPick">' . __('Peak Poller Memory:') . '</td><td>' . ((read_config_option('boost_peak_memory') != '' && is_numeric(read_config_option('boost_peak_memory'))) ? (round(read_config_option('boost_peak_memory')/1024/1024,2)) . ' ' . __('MBytes') : __('N/A')) . '</td>';
+
+		form_alternate_row();
+		print '<td class="utilityPick">' . __('Max Poller Memory Allowed:') . '</td><td>' . ((read_config_option('boost_poller_mem_limit') != '') ? (read_config_option('boost_poller_mem_limit')) . ' ' . __('MBytes') : __('N/A')) . '</td>';
+
+		/* boost last runtime display */
+		html_section_header(__('Detailed Runtime Statistics'), 2);
+
+		form_alternate_row();
+		print '<td class="utilityPick">' . __('Detailed Runtime Timers:') . '</td><td>' . (($detail_stats != '') ? $detail_stats:__('N/A')) . '</td>';
+
+		$runtimes = db_fetch_assoc('SELECT name, value, CAST(replace(name, "stats_boost_", "") AS signed) AS ome
+			FROM settings
+			WHERE name LIKE "stats_boost_%"
+			ORDER BY ome');
+
+		if (cacti_sizeof($runtimes)) {
+			foreach($runtimes as $r) {
+				$process = str_replace('stats_boost_', '', $r['name']);
+				form_alternate_row();
+				print '<td class="utilityPick">' . __esc('Process %d Runtime:', $process) . '</td><td>' . html_escape($r['value']) . '</td>';
+			}
+		}
+
+		/* boost runtime display */
+		html_section_header(__('Run Time Configuration'), 2);
+
+		form_alternate_row();
+		print '<td class="utilityPick">' . __('Update Frequency:') . '</td><td>' . ($rrd_updates == '' ? __('N/A') : $boost_refresh_interval[$update_interval]) . '</td>';
+
+		form_alternate_row();
+		print '<td class="utilityPick">' . __('Concurrent Processes:') . '</td><td>' . read_config_option('boost_parallel') . '</td>';
+
+		form_alternate_row();
+		print '<td class="utilityPick">' . __('Next Start Time:') . '</td><td>' . (is_numeric($next_run_time) ? date('Y-m-d H:i:s', $next_run_time):$next_run_time) . '</td>';
+
+		form_alternate_row();
+		print '<td class="utilityPick">' . __('Maximum Records:') . '</td><td>' . number_format_i18n($max_records, -1) . ' ' . __('Records') . '</td>';
+
+		form_alternate_row();
+		print '<td class="utilityPick">' . __('Maximum Allowed Runtime:') . '</td><td>' . $boost_max_runtime[$max_runtime] . '</td>';
+
+		/* boost caching */
+		html_section_header(__('Image Caching'), 2);
+
+		form_alternate_row();
+		print '<td>' . __('Image Caching Status:') . '</td><td>' . ($boost_cache == '' ? __('Disabled') : __('Enabled')) . '</td>';
+
+		form_alternate_row();
+		print '<td>' . __('Cache Directory:') . '</td><td>' . $cache_directory . '</td>';
+
+		form_alternate_row();
+		print '<td>' . __('Cached Files:') . '</td><td>' . $cache_files . '</td>';
+
+		form_alternate_row();
+		print '<td>' . __('Cached Files Size:') . '</td><td>' . $directory_size . '</td>';
+
+		html_end_box(true);
 	}
-	print '</td>';
-
-	form_alternate_row();
-	print '<td class="utilityPick">' . __('RRD Updates:') . '</td><td>' . ($boost_rrds_updated != '' ? number_format_i18n($boost_rrds_updated, -1):'-') . '</td>';
-
-	form_alternate_row();
-	print '<td class="utilityPick">' . __('Peak Poller Memory:') . '</td><td>' . ((read_config_option('boost_peak_memory') != '' && is_numeric(read_config_option('boost_peak_memory'))) ? (round(read_config_option('boost_peak_memory')/1024/1024,2)) . ' ' . __('MBytes') : __('N/A')) . '</td>';
-
-	form_alternate_row();
-	print '<td class="utilityPick">' . __('Detailed Runtime Timers:') . '</td><td>' . (($detail_stats != '') ? $detail_stats:__('N/A')) . '</td>';
-
-	form_alternate_row();
-	print '<td class="utilityPick">' . __('Max Poller Memory Allowed:') . '</td><td>' . ((read_config_option('boost_poller_mem_limit') != '') ? (read_config_option('boost_poller_mem_limit')) . ' ' . __('MBytes') : __('N/A')) . '</td>';
-
-	/* boost runtime display */
-	html_section_header(__('Run Time Configuration'), 2);
-
-	form_alternate_row();
-	print '<td class="utilityPick">' . __('Update Frequency:') . '</td><td>' . ($rrd_updates == '' ? __('N/A') : $boost_refresh_interval[$update_interval]) . '</td>';
-
-	form_alternate_row();
-	print '<td class="utilityPick">' . __('Next Start Time:') . '</td><td>' . (is_numeric($next_run_time) ? date('Y-m-d H:i:s', $next_run_time):$next_run_time) . '</td>';
-
-	form_alternate_row();
-	print '<td class="utilityPick">' . __('Maximum Records:') . '</td><td>' . number_format_i18n($max_records, -1) . ' ' . __('Records') . '</td>';
-
-	form_alternate_row();
-	print '<td class="utilityPick">' . __('Maximum Allowed Runtime:') . '</td><td>' . $boost_max_runtime[$max_runtime] . '</td>';
-
-	/* boost caching */
-	html_section_header(__('Image Caching'), 2);
-
-	form_alternate_row();
-	print '<td>' . __('Image Caching Status:') . '</td><td>' . ($boost_cache == '' ? __('Disabled') : __('Enabled')) . '</td>';
-
-	form_alternate_row();
-	print '<td>' . __('Cache Directory:') . '</td><td>' . $cache_directory . '</td>';
-
-	form_alternate_row();
-	print '<td>' . __('Cached Files:') . '</td><td>' . $cache_files . '</td>';
-
-	form_alternate_row();
-	print '<td>' . __('Cached Files Size:') . '</td><td>' . $directory_size . '</td>';
-
-	html_end_box(true);
 }
 
 /**
@@ -2501,7 +2622,7 @@ function snmpagent_utilities_run_cache() {
 								<?php
 								if (cacti_sizeof($mibs) > 0) {
 									foreach ($mibs as $mib) {
-										print "<option value='" . $mib['mib'] . "'"; if (get_request_var('mib') == $mib['mib']) { print ' selected'; } print '>' . html_escape($mib['mib']) . '</option>';
+										print "<option value='" . html_escape($mib['mib']) . "'"; if (get_request_var('mib') == $mib['mib']) { print ' selected'; } print '>' . html_escape($mib['mib']) . '</option>';
 									}
 								}
 								?>
@@ -2765,7 +2886,7 @@ function snmpagent_utilities_run_eventlog(){
 								<option value='-1'<?php if (get_request_var('receiver') == '-1') {?> selected<?php }?>><?php print __('Any');?></option>
 								<?php
 								foreach ($receivers as $receiver) {
-									print "<option value='" . $receiver['manager_id'] . "'"; if (get_request_var('receiver') == $receiver['manager_id']) { print ' selected'; } print '>' . $receiver['hostname'] . '</option>';
+									print "<option value='" . $receiver['manager_id'] . "'"; if (get_request_var('receiver') == $receiver['manager_id']) { print ' selected'; } print '>' . html_escape($receiver['hostname']) . '</option>';
 								}
 								?>
 							</select>
